
module Make

# 55 "asllib/Parser.mly"
          (Config : ParserConfig.CONFIG)
# 7 "asllib/Parser.ml"

= struct
  
  module MenhirBasics = struct
    
    exception Error
    
    let _eRR =
      fun _s ->
        raise Error
    
    type token = Tokens.token
    
  end
  
  include MenhirBasics
  
# 63 "asllib/Parser.mly"
  

open AST
open ASTUtils
open Desugar

let version = V1

let t_bit =
  T_Bits (E_Literal (L_Int Z.one) |> add_dummy_annotation ~version, [])

let zero = E_Literal (L_Int Z.zero) |> add_dummy_annotation ~version

let make_ldi_vars (xs, ty) =
  let make_one x =
    S_Decl (LDK_Var, LDI_Var x, Some ty, None)
    |> add_dummy_annotation ~version
  in
  List.map make_one xs |> stmt_from_list |> desc

let make_ty_decl_subtype (x, s) =
  let name, _fields = s.desc in
  let ty = ASTUtils.add_pos_from s (T_Named name) in
  D_TypeDecl (x, ty, Some s.desc)

let prec =
  let open AST in
  function
  | `BOR | `BAND | `IMPL | `BEQ -> 1
  | `EQ_OP | `NEQ -> 2
  | `PLUS | `MINUS | `OR | `XOR | `AND | `CONCAT -> 3
  | `MUL | `DIV | `DIVRM | `RDIV | `MOD | `SHL | `SHR -> 4
  | `POW -> 5
  | `GT | `GEQ | `LT | `LEQ -> 0 (* Non assoc *)

let check_not_same_prec loc op op' =
  if prec op = prec op' then Error.(fatal_from loc CannotParse)

let check_not_binop_same_prec op e =
  match e.desc with
  | E_Binop (op', _, _) when op != op' -> check_not_same_prec e op op'
  | _ -> ()

let e_binop (e1, op, e2) =
  let () = check_not_binop_same_prec op e1
  and () = check_not_binop_same_prec op e2
  in
  E_Binop (op, e1, e2)

let e_call call = E_Call { call with call_type = ST_Function }
let s_call call = S_Call { call with call_type = ST_Procedure }

let le_var x = LE_Var x.desc |> add_pos_from x
let lhs_access ~base ~index ~fields = { base; index; fields; slices=add_dummy_annotation ~version [] }


# 82 "asllib/Parser.ml"
  
  type ('s, 'r) _menhir_state = 
    | MenhirState000 : ('s, _menhir_box_opn) _menhir_state
      (** State 000.
        Stack shape : .
        Start symbol: opn. *)

    | MenhirState001 : (('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_state
      (** State 001.
        Stack shape : WHILE.
        Start symbol: <undetermined>. *)

    | MenhirState004 : (('s, 'r) _menhir_cell1_NOT, 'r) _menhir_state
      (** State 004.
        Stack shape : NOT.
        Start symbol: <undetermined>. *)

    | MenhirState005 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 005.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState006 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 006.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState008 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 008.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState009 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 009.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState010 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 010.
        Stack shape : IDENTIFIER LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState012 : (('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 012.
        Stack shape : BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState015 : (('s, 'r) _menhir_cell1_ARBITRARY, 'r) _menhir_state
      (** State 015.
        Stack shape : ARBITRARY.
        Start symbol: <undetermined>. *)

    | MenhirState018 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 018.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState019 : (('s, 'r) _menhir_cell1_INTEGER, 'r) _menhir_state
      (** State 019.
        Stack shape : INTEGER.
        Start symbol: <undetermined>. *)

    | MenhirState020 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 020.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState021 : ((('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 021.
        Stack shape : LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState024 : ((('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 024.
        Stack shape : MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState025 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 025.
        Stack shape : expr LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState026 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 026.
        Stack shape : expr LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState027 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_XOR, 'r) _menhir_state
      (** State 027.
        Stack shape : expr XOR.
        Start symbol: <undetermined>. *)

    | MenhirState028 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_XOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 028.
        Stack shape : expr XOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState029 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHR, 'r) _menhir_state
      (** State 029.
        Stack shape : expr SHR.
        Start symbol: <undetermined>. *)

    | MenhirState030 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 030.
        Stack shape : expr SHR expr.
        Start symbol: <undetermined>. *)

    | MenhirState031 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_POW, 'r) _menhir_state
      (** State 031.
        Stack shape : expr POW.
        Start symbol: <undetermined>. *)

    | MenhirState032 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_POW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 032.
        Stack shape : expr POW expr.
        Start symbol: <undetermined>. *)

    | MenhirState033 : (('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_state
      (** State 033.
        Stack shape : LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState034 : (('s, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 034.
        Stack shape : COLON.
        Start symbol: <undetermined>. *)

    | MenhirState035 : ((('s, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 035.
        Stack shape : COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState036 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHL, 'r) _menhir_state
      (** State 036.
        Stack shape : expr SHL.
        Start symbol: <undetermined>. *)

    | MenhirState037 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 037.
        Stack shape : expr SHL expr.
        Start symbol: <undetermined>. *)

    | MenhirState038 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IN, 'r) _menhir_state
      (** State 038.
        Stack shape : expr IN.
        Start symbol: <undetermined>. *)

    | MenhirState039 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 039.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState040 : (('s, 'r) _menhir_cell1_NOT, 'r) _menhir_state
      (** State 040.
        Stack shape : NOT.
        Start symbol: <undetermined>. *)

    | MenhirState041 : ((('s, 'r) _menhir_cell1_NOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 041.
        Stack shape : NOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState043 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 043.
        Stack shape : expr DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState045 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 045.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState052 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 052.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState053 : ((('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 053.
        Stack shape : MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState055 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 055.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState056 : (('s, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 056.
        Stack shape : LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState057 : ((('s, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 057.
        Stack shape : LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState058 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RDIV, 'r) _menhir_state
      (** State 058.
        Stack shape : expr RDIV.
        Start symbol: <undetermined>. *)

    | MenhirState059 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RDIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 059.
        Stack shape : expr RDIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState060 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS, 'r) _menhir_state
      (** State 060.
        Stack shape : expr PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState061 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 061.
        Stack shape : expr PLUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState062 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MUL, 'r) _menhir_state
      (** State 062.
        Stack shape : expr MUL.
        Start symbol: <undetermined>. *)

    | MenhirState063 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MUL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 063.
        Stack shape : expr MUL expr.
        Start symbol: <undetermined>. *)

    | MenhirState064 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MOD, 'r) _menhir_state
      (** State 064.
        Stack shape : expr MOD.
        Start symbol: <undetermined>. *)

    | MenhirState065 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MOD, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 065.
        Stack shape : expr MOD expr.
        Start symbol: <undetermined>. *)

    | MenhirState066 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIVRM, 'r) _menhir_state
      (** State 066.
        Stack shape : expr DIVRM.
        Start symbol: <undetermined>. *)

    | MenhirState067 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIVRM, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 067.
        Stack shape : expr DIVRM expr.
        Start symbol: <undetermined>. *)

    | MenhirState068 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIV, 'r) _menhir_state
      (** State 068.
        Stack shape : expr DIV.
        Start symbol: <undetermined>. *)

    | MenhirState069 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 069.
        Stack shape : expr DIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState070 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OR, 'r) _menhir_state
      (** State 070.
        Stack shape : expr OR.
        Start symbol: <undetermined>. *)

    | MenhirState071 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 071.
        Stack shape : expr OR expr.
        Start symbol: <undetermined>. *)

    | MenhirState072 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_NEQ, 'r) _menhir_state
      (** State 072.
        Stack shape : expr NEQ.
        Start symbol: <undetermined>. *)

    | MenhirState074 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_NEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 074.
        Stack shape : expr NEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState075 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 075.
        Stack shape : expr MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState076 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 076.
        Stack shape : expr MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState077 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LT, 'r) _menhir_state
      (** State 077.
        Stack shape : expr LT.
        Start symbol: <undetermined>. *)

    | MenhirState078 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 078.
        Stack shape : expr LT expr.
        Start symbol: <undetermined>. *)

    | MenhirState079 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_state
      (** State 079.
        Stack shape : expr COLON_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState080 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 080.
        Stack shape : expr COLON_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState081 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AND, 'r) _menhir_state
      (** State 081.
        Stack shape : expr AND.
        Start symbol: <undetermined>. *)

    | MenhirState082 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 082.
        Stack shape : expr AND expr.
        Start symbol: <undetermined>. *)

    | MenhirState083 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 083.
        Stack shape : expr LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState084 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 084.
        Stack shape : expr LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState085 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GT, 'r) _menhir_state
      (** State 085.
        Stack shape : expr GT.
        Start symbol: <undetermined>. *)

    | MenhirState086 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 086.
        Stack shape : expr GT expr.
        Start symbol: <undetermined>. *)

    | MenhirState087 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 087.
        Stack shape : expr GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState088 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 088.
        Stack shape : expr GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState089 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IMPL, 'r) _menhir_state
      (** State 089.
        Stack shape : expr IMPL.
        Start symbol: <undetermined>. *)

    | MenhirState090 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IMPL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 090.
        Stack shape : expr IMPL expr.
        Start symbol: <undetermined>. *)

    | MenhirState091 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_state
      (** State 091.
        Stack shape : expr EQ_OP.
        Start symbol: <undetermined>. *)

    | MenhirState093 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 093.
        Stack shape : expr EQ_OP expr.
        Start symbol: <undetermined>. *)

    | MenhirState094 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BOR, 'r) _menhir_state
      (** State 094.
        Stack shape : expr BOR.
        Start symbol: <undetermined>. *)

    | MenhirState095 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 095.
        Stack shape : expr BOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState096 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BEQ, 'r) _menhir_state
      (** State 096.
        Stack shape : expr BEQ.
        Start symbol: <undetermined>. *)

    | MenhirState097 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 097.
        Stack shape : expr BEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState098 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BAND, 'r) _menhir_state
      (** State 098.
        Stack shape : expr BAND.
        Start symbol: <undetermined>. *)

    | MenhirState099 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BAND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 099.
        Stack shape : expr BAND expr.
        Start symbol: <undetermined>. *)

    | MenhirState100 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AS, 'r) _menhir_state
      (** State 100.
        Stack shape : expr AS.
        Start symbol: <undetermined>. *)

    | MenhirState104 : (('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 104.
        Stack shape : BITS LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState105 : ((('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 105.
        Stack shape : BITS LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState106 : (((('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR, 'r) _menhir_state
      (** State 106.
        Stack shape : BITS LPAR expr RPAR.
        Start symbol: <undetermined>. *)

    | MenhirState107 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 107.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState112 : (('s, 'r) _menhir_cell1_slices _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 112.
        Stack shape : slices IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState113 : (('s, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 113.
        Stack shape : COLON.
        Start symbol: <undetermined>. *)

    | MenhirState116 : (('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_state
      (** State 116.
        Stack shape : ARRAY.
        Start symbol: <undetermined>. *)

    | MenhirState117 : ((('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 117.
        Stack shape : ARRAY expr.
        Start symbol: <undetermined>. *)

    | MenhirState119 : (((('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RRBRACKET, 'r) _menhir_state
      (** State 119.
        Stack shape : ARRAY expr RRBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState125 : (('s, 'r) _menhir_cell1_bitfield, 'r) _menhir_state
      (** State 125.
        Stack shape : bitfield.
        Start symbol: <undetermined>. *)

    | MenhirState131 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 131.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState132 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 132.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState133 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 133.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState134 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 134.
        Stack shape : IF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState135 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_state
      (** State 135.
        Stack shape : expr THEN expr ELSIF.
        Start symbol: <undetermined>. *)

    | MenhirState136 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 136.
        Stack shape : expr THEN expr ELSIF expr.
        Start symbol: <undetermined>. *)

    | MenhirState137 : ((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 137.
        Stack shape : expr THEN expr ELSIF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState138 : (((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 138.
        Stack shape : expr THEN expr ELSIF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState139 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSE, 'r) _menhir_state
      (** State 139.
        Stack shape : expr THEN expr ELSE.
        Start symbol: <undetermined>. *)

    | MenhirState140 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 140.
        Stack shape : expr THEN expr ELSE expr.
        Start symbol: <undetermined>. *)

    | MenhirState143 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 143.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState144 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 144.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState145 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 145.
        Stack shape : IDENTIFIER LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState147 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 147.
        Stack shape : IDENTIFIER LBRACE IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState148 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 148.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState149 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 149.
        Stack shape : IDENTIFIER LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState152 : (('s, 'r) _menhir_cell1_field_assign, 'r) _menhir_state
      (** State 152.
        Stack shape : field_assign.
        Start symbol: <undetermined>. *)

    | MenhirState153 : ((('s, 'r) _menhir_cell1_field_assign, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 153.
        Stack shape : field_assign IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState154 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 154.
        Stack shape : IDENTIFIER EQ.
        Start symbol: <undetermined>. *)

    | MenhirState155 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 155.
        Stack shape : IDENTIFIER EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState157 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 157.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState158 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 158.
        Stack shape : expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState164 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 164.
        Stack shape : IDENTIFIER LBRACE clist1(expr) RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState170 : (('s, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 170.
        Stack shape : GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState171 : ((('s, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 171.
        Stack shape : GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState172 : (('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 172.
        Stack shape : BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState173 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 173.
        Stack shape : BNOT LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState175 : (('s, 'r) _menhir_cell1_ARBITRARY, 'r) _menhir_state
      (** State 175.
        Stack shape : ARBITRARY.
        Start symbol: <undetermined>. *)

    | MenhirState182 : (('s, 'r) _menhir_cell1_pattern, 'r) _menhir_state
      (** State 182.
        Stack shape : pattern.
        Start symbol: <undetermined>. *)

    | MenhirState183 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 183.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState184 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_XOR, 'r) _menhir_state
      (** State 184.
        Stack shape : expr_pattern XOR.
        Start symbol: <undetermined>. *)

    | MenhirState185 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_XOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 185.
        Stack shape : expr_pattern XOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState186 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SLICING, 'r) _menhir_state
      (** State 186.
        Stack shape : expr_pattern SLICING.
        Start symbol: <undetermined>. *)

    | MenhirState187 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SLICING, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 187.
        Stack shape : expr_pattern SLICING expr.
        Start symbol: <undetermined>. *)

    | MenhirState188 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHR, 'r) _menhir_state
      (** State 188.
        Stack shape : expr_pattern SHR.
        Start symbol: <undetermined>. *)

    | MenhirState189 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 189.
        Stack shape : expr_pattern SHR expr.
        Start symbol: <undetermined>. *)

    | MenhirState190 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHL, 'r) _menhir_state
      (** State 190.
        Stack shape : expr_pattern SHL.
        Start symbol: <undetermined>. *)

    | MenhirState191 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 191.
        Stack shape : expr_pattern SHL expr.
        Start symbol: <undetermined>. *)

    | MenhirState192 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_RDIV, 'r) _menhir_state
      (** State 192.
        Stack shape : expr_pattern RDIV.
        Start symbol: <undetermined>. *)

    | MenhirState193 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_RDIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 193.
        Stack shape : expr_pattern RDIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState194 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_POW, 'r) _menhir_state
      (** State 194.
        Stack shape : expr_pattern POW.
        Start symbol: <undetermined>. *)

    | MenhirState195 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_POW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 195.
        Stack shape : expr_pattern POW expr.
        Start symbol: <undetermined>. *)

    | MenhirState196 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_PLUS, 'r) _menhir_state
      (** State 196.
        Stack shape : expr_pattern PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState197 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_PLUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 197.
        Stack shape : expr_pattern PLUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState198 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_OR, 'r) _menhir_state
      (** State 198.
        Stack shape : expr_pattern OR.
        Start symbol: <undetermined>. *)

    | MenhirState199 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_OR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 199.
        Stack shape : expr_pattern OR expr.
        Start symbol: <undetermined>. *)

    | MenhirState200 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_NEQ, 'r) _menhir_state
      (** State 200.
        Stack shape : expr_pattern NEQ.
        Start symbol: <undetermined>. *)

    | MenhirState202 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_NEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 202.
        Stack shape : expr_pattern NEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState203 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MUL, 'r) _menhir_state
      (** State 203.
        Stack shape : expr_pattern MUL.
        Start symbol: <undetermined>. *)

    | MenhirState204 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MUL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 204.
        Stack shape : expr_pattern MUL expr.
        Start symbol: <undetermined>. *)

    | MenhirState205 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MOD, 'r) _menhir_state
      (** State 205.
        Stack shape : expr_pattern MOD.
        Start symbol: <undetermined>. *)

    | MenhirState206 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MOD, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 206.
        Stack shape : expr_pattern MOD expr.
        Start symbol: <undetermined>. *)

    | MenhirState207 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 207.
        Stack shape : expr_pattern MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState208 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 208.
        Stack shape : expr_pattern MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState209 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LT, 'r) _menhir_state
      (** State 209.
        Stack shape : expr_pattern LT.
        Start symbol: <undetermined>. *)

    | MenhirState210 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 210.
        Stack shape : expr_pattern LT expr.
        Start symbol: <undetermined>. *)

    | MenhirState211 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 211.
        Stack shape : expr_pattern LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState212 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 212.
        Stack shape : expr_pattern LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState214 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 214.
        Stack shape : expr_pattern LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState215 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 215.
        Stack shape : expr_pattern LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState216 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IN, 'r) _menhir_state
      (** State 216.
        Stack shape : expr_pattern IN.
        Start symbol: <undetermined>. *)

    | MenhirState217 : ((('s, 'r) _menhir_cell1_IN, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 217.
        Stack shape : IN BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState219 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IMPL, 'r) _menhir_state
      (** State 219.
        Stack shape : expr_pattern IMPL.
        Start symbol: <undetermined>. *)

    | MenhirState220 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IMPL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 220.
        Stack shape : expr_pattern IMPL expr.
        Start symbol: <undetermined>. *)

    | MenhirState221 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GT, 'r) _menhir_state
      (** State 221.
        Stack shape : expr_pattern GT.
        Start symbol: <undetermined>. *)

    | MenhirState222 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 222.
        Stack shape : expr_pattern GT expr.
        Start symbol: <undetermined>. *)

    | MenhirState223 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 223.
        Stack shape : expr_pattern GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState224 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 224.
        Stack shape : expr_pattern GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState225 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_state
      (** State 225.
        Stack shape : expr_pattern EQ_OP.
        Start symbol: <undetermined>. *)

    | MenhirState227 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 227.
        Stack shape : expr_pattern EQ_OP expr.
        Start symbol: <undetermined>. *)

    | MenhirState229 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 229.
        Stack shape : expr_pattern DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState233 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIVRM, 'r) _menhir_state
      (** State 233.
        Stack shape : expr_pattern DIVRM.
        Start symbol: <undetermined>. *)

    | MenhirState234 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIVRM, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 234.
        Stack shape : expr_pattern DIVRM expr.
        Start symbol: <undetermined>. *)

    | MenhirState235 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIV, 'r) _menhir_state
      (** State 235.
        Stack shape : expr_pattern DIV.
        Start symbol: <undetermined>. *)

    | MenhirState236 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 236.
        Stack shape : expr_pattern DIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState237 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_state
      (** State 237.
        Stack shape : expr_pattern COLON_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState238 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 238.
        Stack shape : expr_pattern COLON_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState239 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BOR, 'r) _menhir_state
      (** State 239.
        Stack shape : expr_pattern BOR.
        Start symbol: <undetermined>. *)

    | MenhirState240 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 240.
        Stack shape : expr_pattern BOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState241 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BEQ, 'r) _menhir_state
      (** State 241.
        Stack shape : expr_pattern BEQ.
        Start symbol: <undetermined>. *)

    | MenhirState242 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 242.
        Stack shape : expr_pattern BEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState243 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BAND, 'r) _menhir_state
      (** State 243.
        Stack shape : expr_pattern BAND.
        Start symbol: <undetermined>. *)

    | MenhirState244 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BAND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 244.
        Stack shape : expr_pattern BAND expr.
        Start symbol: <undetermined>. *)

    | MenhirState245 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AS, 'r) _menhir_state
      (** State 245.
        Stack shape : expr_pattern AS.
        Start symbol: <undetermined>. *)

    | MenhirState248 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AND, 'r) _menhir_state
      (** State 248.
        Stack shape : expr_pattern AND.
        Start symbol: <undetermined>. *)

    | MenhirState249 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 249.
        Stack shape : expr_pattern AND expr.
        Start symbol: <undetermined>. *)

    | MenhirState254 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 254.
        Stack shape : BNOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState256 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_pattern, 'r) _menhir_state
      (** State 256.
        Stack shape : LPAR pattern.
        Start symbol: <undetermined>. *)

    | MenhirState258 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 258.
        Stack shape : LPAR expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState266 : (('s, 'r) _menhir_cell1_slice, 'r) _menhir_state
      (** State 266.
        Stack shape : slice.
        Start symbol: <undetermined>. *)

    | MenhirState267 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 267.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState268 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_state
      (** State 268.
        Stack shape : expr STAR_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState269 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 269.
        Stack shape : expr STAR_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState270 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_state
      (** State 270.
        Stack shape : expr PLUS_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState271 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 271.
        Stack shape : expr PLUS_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState272 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 272.
        Stack shape : expr COLON.
        Start symbol: <undetermined>. *)

    | MenhirState273 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 273.
        Stack shape : expr COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState279 : (('s, 'r) _menhir_cell1_int_constraint, 'r) _menhir_state
      (** State 279.
        Stack shape : int_constraint.
        Start symbol: <undetermined>. *)

    | MenhirState280 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 280.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState281 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_state
      (** State 281.
        Stack shape : expr SLICING.
        Start symbol: <undetermined>. *)

    | MenhirState282 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 282.
        Stack shape : expr SLICING expr.
        Start symbol: <undetermined>. *)

    | MenhirState289 : (('s, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 289.
        Stack shape : ty.
        Start symbol: <undetermined>. *)

    | MenhirState295 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 295.
        Stack shape : BNOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState298 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 298.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState299 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 299.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState300 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 300.
        Stack shape : IF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState302 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 302.
        Stack shape : LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState304 : (((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 304.
        Stack shape : LPAR expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState308 : ((('s, 'r) _menhir_cell1_NOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 308.
        Stack shape : NOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState309 : ((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 309.
        Stack shape : WHILE expr.
        Start symbol: <undetermined>. *)

    | MenhirState310 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_state
      (** State 310.
        Stack shape : expr LOOPLIMIT.
        Start symbol: <undetermined>. *)

    | MenhirState311 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 311.
        Stack shape : expr LOOPLIMIT expr.
        Start symbol: <undetermined>. *)

    | MenhirState313 : (((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_loop_limit, 'r) _menhir_state
      (** State 313.
        Stack shape : WHILE expr loop_limit.
        Start symbol: <undetermined>. *)

    | MenhirState314 : (('s, 'r) _menhir_cell1_VAR, 'r) _menhir_state
      (** State 314.
        Stack shape : VAR.
        Start symbol: <undetermined>. *)

    | MenhirState316 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 316.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState320 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_state
      (** State 320.
        Stack shape : LPAR discard_or_identifier.
        Start symbol: <undetermined>. *)

    | MenhirState322 : ((('s, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_state
      (** State 322.
        Stack shape : discard_or_identifier discard_or_identifier.
        Start symbol: <undetermined>. *)

    | MenhirState328 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 328.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState330 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 330.
        Stack shape : VAR decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState331 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 331.
        Stack shape : VAR decl_item EQ.
        Start symbol: <undetermined>. *)

    | MenhirState332 : ((('s, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 332.
        Stack shape : EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState335 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_state
      (** State 335.
        Stack shape : VAR decl_item as_ty.
        Start symbol: <undetermined>. *)

    | MenhirState336 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 336.
        Stack shape : VAR decl_item as_ty EQ.
        Start symbol: <undetermined>. *)

    | MenhirState337 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 337.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState338 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 338.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState340 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 340.
        Stack shape : IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState343 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 343.
        Stack shape : IDENTIFIER LBRACE COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState346 : ((((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 346.
        Stack shape : IDENTIFIER LBRACE COMMA clist1(expr) RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState353 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_clist2_IDENTIFIER_, 'r) _menhir_state
      (** State 353.
        Stack shape : VAR clist2(IDENTIFIER).
        Start symbol: <undetermined>. *)

    | MenhirState360 : (('s, 'r) _menhir_cell1_TRY, 'r) _menhir_state
      (** State 360.
        Stack shape : TRY.
        Start symbol: <undetermined>. *)

    | MenhirState361 : (('s, 'r) _menhir_cell1_THROW, 'r) _menhir_state
      (** State 361.
        Stack shape : THROW.
        Start symbol: <undetermined>. *)

    | MenhirState363 : ((('s, 'r) _menhir_cell1_THROW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 363.
        Stack shape : THROW expr.
        Start symbol: <undetermined>. *)

    | MenhirState365 : (('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_state
      (** State 365.
        Stack shape : RETURN.
        Start symbol: <undetermined>. *)

    | MenhirState368 : ((('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 368.
        Stack shape : RETURN expr.
        Start symbol: <undetermined>. *)

    | MenhirState369 : (('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_state
      (** State 369.
        Stack shape : REPEAT.
        Start symbol: <undetermined>. *)

    | MenhirState371 : (('s, 'r) _menhir_cell1_PRINTLN _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 371.
        Stack shape : PRINTLN LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState376 : (('s, 'r) _menhir_cell1_PRINT _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 376.
        Stack shape : PRINT LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState381 : (('s, 'r) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 381.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState387 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 387.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState389 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 389.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState390 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 390.
        Stack shape : IDENTIFIER LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState391 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 391.
        Stack shape : IDENTIFIER LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState392 : ((((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RRBRACKET, 'r) _menhir_state
      (** State 392.
        Stack shape : IDENTIFIER LLBRACKET expr RRBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState394 : (('s, 'r) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 394.
        Stack shape : DOT IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState400 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_discard_or_sliced_basic_lexpr, 'r) _menhir_state
      (** State 400.
        Stack shape : LPAR discard_or_sliced_basic_lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState402 : ((('s, 'r) _menhir_cell1_discard_or_sliced_basic_lexpr, 'r) _menhir_cell1_discard_or_sliced_basic_lexpr, 'r) _menhir_state
      (** State 402.
        Stack shape : discard_or_sliced_basic_lexpr discard_or_sliced_basic_lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState404 : (('s, 'r) _menhir_cell1_basic_lexpr, 'r) _menhir_state
      (** State 404.
        Stack shape : basic_lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState410 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 410.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState411 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 411.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState412 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 412.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState413 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 413.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState414 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 414.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState416 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 416.
        Stack shape : IDENTIFIER DOT LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState420 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LPAR, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_state
      (** State 420.
        Stack shape : IDENTIFIER DOT LPAR discard_or_field.
        Start symbol: <undetermined>. *)

    | MenhirState422 : ((('s, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_state
      (** State 422.
        Stack shape : discard_or_field discard_or_field.
        Start symbol: <undetermined>. *)

    | MenhirState427 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 427.
        Stack shape : IDENTIFIER DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState433 : (('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 433.
        Stack shape : FOR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState434 : ((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 434.
        Stack shape : FOR IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState437 : (((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_state
      (** State 437.
        Stack shape : FOR IDENTIFIER expr direction.
        Start symbol: <undetermined>. *)

    | MenhirState438 : ((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 438.
        Stack shape : FOR IDENTIFIER expr direction expr.
        Start symbol: <undetermined>. *)

    | MenhirState440 : (((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_loop_limit, 'r) _menhir_state
      (** State 440.
        Stack shape : FOR IDENTIFIER expr direction expr loop_limit.
        Start symbol: <undetermined>. *)

    | MenhirState442 : (('s, 'r) _menhir_cell1_DEBUG _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 442.
        Stack shape : DEBUG LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState447 : (('s, 'r) _menhir_cell1_CASE, 'r) _menhir_state
      (** State 447.
        Stack shape : CASE.
        Start symbol: <undetermined>. *)

    | MenhirState448 : ((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 448.
        Stack shape : CASE expr.
        Start symbol: <undetermined>. *)

    | MenhirState449 : (((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_state
      (** State 449.
        Stack shape : CASE expr OF.
        Start symbol: <undetermined>. *)

    | MenhirState450 : (('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_state
      (** State 450.
        Stack shape : WHEN.
        Start symbol: <undetermined>. *)

    | MenhirState452 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_state
      (** State 452.
        Stack shape : WHEN pattern_list.
        Start symbol: <undetermined>. *)

    | MenhirState453 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 453.
        Stack shape : WHEN pattern_list expr.
        Start symbol: <undetermined>. *)

    | MenhirState454 : ((((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ARROW, 'r) _menhir_state
      (** State 454.
        Stack shape : WHEN pattern_list expr ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState455 : (('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_state
      (** State 455.
        Stack shape : ASSERT.
        Start symbol: <undetermined>. *)

    | MenhirState456 : ((('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 456.
        Stack shape : ASSERT expr.
        Start symbol: <undetermined>. *)

    | MenhirState459 : (('s, 'r) _menhir_cell1_stmt, 'r) _menhir_state
      (** State 459.
        Stack shape : stmt.
        Start symbol: <undetermined>. *)

    | MenhirState461 : (('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_state
      (** State 461.
        Stack shape : local_decl_keyword_non_var.
        Start symbol: <undetermined>. *)

    | MenhirState463 : ((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 463.
        Stack shape : local_decl_keyword_non_var decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState464 : (((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 464.
        Stack shape : local_decl_keyword_non_var decl_item EQ.
        Start symbol: <undetermined>. *)

    | MenhirState465 : ((((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 465.
        Stack shape : local_decl_keyword_non_var decl_item EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState468 : (((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_state
      (** State 468.
        Stack shape : local_decl_keyword_non_var decl_item as_ty.
        Start symbol: <undetermined>. *)

    | MenhirState469 : ((((('s, 'r) _menhir_cell1_local_decl_keyword_non_var, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 469.
        Stack shape : local_decl_keyword_non_var decl_item as_ty expr.
        Start symbol: <undetermined>. *)

    | MenhirState475 : (('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_state
      (** State 475.
        Stack shape : lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState476 : ((('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 476.
        Stack shape : lexpr expr.
        Start symbol: <undetermined>. *)

    | MenhirState480 : (('s, 'r) _menhir_cell1_call, 'r) _menhir_state
      (** State 480.
        Stack shape : call.
        Start symbol: <undetermined>. *)

    | MenhirState481 : ((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 481.
        Stack shape : call expr.
        Start symbol: <undetermined>. *)

    | MenhirState484 : (('s, 'r) _menhir_cell1_call _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 484.
        Stack shape : call LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState487 : ((('s, 'r) _menhir_cell1_call _menhir_cell0_LBRACKET, 'r) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_state
      (** State 487.
        Stack shape : call LBRACKET clist2(IDENTIFIER) RBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState488 : (((('s, 'r) _menhir_cell1_call _menhir_cell0_LBRACKET, 'r) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 488.
        Stack shape : call LBRACKET clist2(IDENTIFIER) RBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState491 : (('s, 'r) _menhir_cell1_call _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 491.
        Stack shape : call IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState492 : ((('s, 'r) _menhir_cell1_call _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 492.
        Stack shape : call IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState495 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_state
      (** State 495.
        Stack shape : WHEN pattern_list.
        Start symbol: <undetermined>. *)

    | MenhirState499 : ((((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_cell1_list1_case_alt_, 'r) _menhir_state
      (** State 499.
        Stack shape : CASE expr OF list1(case_alt).
        Start symbol: <undetermined>. *)

    | MenhirState505 : (('s, 'r) _menhir_cell1_case_alt, 'r) _menhir_state
      (** State 505.
        Stack shape : case_alt.
        Start symbol: <undetermined>. *)

    | MenhirState510 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 510.
        Stack shape : IF expr THEN stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState511 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_state
      (** State 511.
        Stack shape : expr THEN stmt_list ELSIF.
        Start symbol: <undetermined>. *)

    | MenhirState512 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 512.
        Stack shape : expr THEN stmt_list ELSIF expr.
        Start symbol: <undetermined>. *)

    | MenhirState513 : ((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 513.
        Stack shape : expr THEN stmt_list ELSIF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState514 : (((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 514.
        Stack shape : expr THEN stmt_list ELSIF expr THEN stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState515 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSE, 'r) _menhir_state
      (** State 515.
        Stack shape : expr THEN stmt_list ELSE.
        Start symbol: <undetermined>. *)

    | MenhirState522 : ((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 522.
        Stack shape : REPEAT stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState523 : (((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 523.
        Stack shape : REPEAT stmt_list expr.
        Start symbol: <undetermined>. *)

    | MenhirState527 : ((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 527.
        Stack shape : TRY stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState528 : (('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_state
      (** State 528.
        Stack shape : WHEN.
        Start symbol: <undetermined>. *)

    | MenhirState530 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 530.
        Stack shape : WHEN IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState532 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 532.
        Stack shape : WHEN IDENTIFIER ty.
        Start symbol: <undetermined>. *)

    | MenhirState535 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 535.
        Stack shape : WHEN ty.
        Start symbol: <undetermined>. *)

    | MenhirState539 : (((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_list1_catcher_, 'r) _menhir_state
      (** State 539.
        Stack shape : TRY stmt_list list1(catcher).
        Start symbol: <undetermined>. *)

    | MenhirState544 : (('s, 'r) _menhir_cell1_catcher, 'r) _menhir_state
      (** State 544.
        Stack shape : catcher.
        Start symbol: <undetermined>. *)

    | MenhirState552 : ('s, _menhir_box_spec) _menhir_state
      (** State 552.
        Stack shape : .
        Start symbol: spec. *)

    | MenhirState553 : (('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_state
      (** State 553.
        Stack shape : VAR.
        Start symbol: spec. *)

    | MenhirState556 : ((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 556.
        Stack shape : VAR ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState558 : (((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_, _menhir_box_spec) _menhir_state
      (** State 558.
        Stack shape : VAR ignored_or_identifier option(as_ty).
        Start symbol: spec. *)

    | MenhirState559 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 559.
        Stack shape : VAR ignored_or_identifier option(as_ty) expr.
        Start symbol: spec. *)

    | MenhirState564 : (('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 564.
        Stack shape : TYPE IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState567 : (('s, _menhir_box_spec) _menhir_cell1_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 567.
        Stack shape : SUBTYPES IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState568 : (('s, _menhir_box_spec) _menhir_cell1_LBRACE, _menhir_box_spec) _menhir_state
      (** State 568.
        Stack shape : LBRACE.
        Start symbol: spec. *)

    | MenhirState571 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 571.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState574 : (('s, _menhir_box_spec) _menhir_cell1_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 574.
        Stack shape : typed_identifier.
        Start symbol: spec. *)

    | MenhirState579 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_state
      (** State 579.
        Stack shape : TYPE IDENTIFIER OF.
        Start symbol: spec. *)

    | MenhirState580 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_RECORD, _menhir_box_spec) _menhir_state
      (** State 580.
        Stack shape : TYPE IDENTIFIER OF RECORD.
        Start symbol: spec. *)

    | MenhirState583 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_EXCEPTION, _menhir_box_spec) _menhir_state
      (** State 583.
        Stack shape : TYPE IDENTIFIER OF EXCEPTION.
        Start symbol: spec. *)

    | MenhirState586 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ENUMERATION _menhir_cell0_LBRACE, _menhir_box_spec) _menhir_state
      (** State 586.
        Stack shape : TYPE IDENTIFIER OF ENUMERATION LBRACE.
        Start symbol: spec. *)

    | MenhirState588 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 588.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState592 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_COLLECTION, _menhir_box_spec) _menhir_state
      (** State 592.
        Stack shape : TYPE IDENTIFIER OF COLLECTION.
        Start symbol: spec. *)

    | MenhirState594 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl, _menhir_box_spec) _menhir_state
      (** State 594.
        Stack shape : TYPE IDENTIFIER OF ty_decl.
        Start symbol: spec. *)

    | MenhirState602 : (('s, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 602.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState608 : (('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 608.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState609 : (('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_LBRACE, _menhir_box_spec) _menhir_state
      (** State 609.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: spec. *)

    | MenhirState610 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 610.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState613 : (('s, _menhir_box_spec) _menhir_cell1_opt_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 613.
        Stack shape : opt_typed_identifier.
        Start symbol: spec. *)

    | MenhirState617 : ((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 617.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState618 : ((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR, _menhir_box_spec) _menhir_state
      (** State 618.
        Stack shape : IDENTIFIER params_opt LPAR.
        Start symbol: spec. *)

    | MenhirState620 : (('s, _menhir_box_spec) _menhir_cell1_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 620.
        Stack shape : typed_identifier.
        Start symbol: spec. *)

    | MenhirState625 : (((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 625.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState626 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 626.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState631 : (((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_ARROW, _menhir_box_spec) _menhir_state
      (** State 631.
        Stack shape : IDENTIFIER params_opt func_args ARROW.
        Start symbol: spec. *)

    | MenhirState633 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 633.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState634 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT, _menhir_box_spec) _menhir_state
      (** State 634.
        Stack shape : IDENTIFIER params_opt func_args return_type RECURSELIMIT.
        Start symbol: spec. *)

    | MenhirState635 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 635.
        Stack shape : IDENTIFIER params_opt func_args return_type RECURSELIMIT expr.
        Start symbol: spec. *)

    | MenhirState637 : (((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 637.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState642 : (('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 642.
        Stack shape : IMPLEMENTATION IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState643 : ((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 643.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState646 : (((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 646.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState648 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 648.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState649 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_state
      (** State 649.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER.
        Start symbol: spec. *)

    | MenhirState653 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 653.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER maybe_empty_stmt_list END SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState657 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_state
      (** State 657.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER maybe_empty_stmt_list END.
        Start symbol: spec. *)

    | MenhirState661 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_state
      (** State 661.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty GETTER.
        Start symbol: spec. *)

    | MenhirState664 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_state
      (** State 664.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty GETTER maybe_empty_stmt_list END.
        Start symbol: spec. *)

    | MenhirState669 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 669.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty GETTER maybe_empty_stmt_list END SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState678 : (('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 678.
        Stack shape : IMPDEF FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState679 : ((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 679.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState680 : (((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 680.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState681 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 681.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState685 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 685.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState687 : (((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 687.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState692 : (('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 692.
        Stack shape : IMPDEF IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState693 : ((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 693.
        Stack shape : IMPDEF IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState696 : (((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 696.
        Stack shape : IMPDEF IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState698 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 698.
        Stack shape : IMPDEF IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState703 : (('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 703.
        Stack shape : FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState704 : ((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 704.
        Stack shape : FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState705 : (((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 705.
        Stack shape : FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState706 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 706.
        Stack shape : FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState710 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 710.
        Stack shape : FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState712 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 712.
        Stack shape : FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState717 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_state
      (** State 717.
        Stack shape : CONFIG.
        Start symbol: spec. *)

    | MenhirState718 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 718.
        Stack shape : CONFIG ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState720 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 720.
        Stack shape : CONFIG ignored_or_identifier as_ty.
        Start symbol: spec. *)

    | MenhirState721 : ((((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 721.
        Stack shape : CONFIG ignored_or_identifier as_ty expr.
        Start symbol: spec. *)

    | MenhirState724 : (('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 724.
        Stack shape : ACCESSOR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState725 : ((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 725.
        Stack shape : ACCESSOR IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState728 : (((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 728.
        Stack shape : ACCESSOR IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState730 : ((((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 730.
        Stack shape : ACCESSOR IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState737 : (('s, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_state
      (** State 737.
        Stack shape : global_let_or_constant.
        Start symbol: spec. *)

    | MenhirState738 : ((('s, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 738.
        Stack shape : global_let_or_constant ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState740 : (((('s, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_, _menhir_box_spec) _menhir_state
      (** State 740.
        Stack shape : global_let_or_constant ignored_or_identifier option(as_ty).
        Start symbol: spec. *)

    | MenhirState741 : ((((('s, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 741.
        Stack shape : global_let_or_constant ignored_or_identifier option(as_ty) expr.
        Start symbol: spec. *)

    | MenhirState744 : (('s, _menhir_box_spec) _menhir_cell1_decl, _menhir_box_spec) _menhir_state
      (** State 744.
        Stack shape : decl.
        Start symbol: spec. *)

    | MenhirState746 : ('s, _menhir_box_stmts) _menhir_state
      (** State 746.
        Stack shape : .
        Start symbol: stmts. *)

  
  and ('s, 'r) _menhir_cell1_as_ty = 
    | MenhirCell1_as_ty of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_basic_lexpr = 
    | MenhirCell1_basic_lexpr of 's * ('s, 'r) _menhir_state * (Desugar.lhs_access) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_bitfield = 
    | MenhirCell1_bitfield of 's * ('s, 'r) _menhir_state * (AST.bitfield)
  
  and ('s, 'r) _menhir_cell1_call = 
    | MenhirCell1_call of 's * ('s, 'r) _menhir_state * (AST.call) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_case_alt = 
    | MenhirCell1_case_alt of 's * ('s, 'r) _menhir_state * (AST.case_alt_desc AST.annotated)
  
  and ('s, 'r) _menhir_cell1_catcher = 
    | MenhirCell1_catcher of 's * ('s, 'r) _menhir_state * (AST.catcher)
  
  and ('s, 'r) _menhir_cell1_clist1_expr_ = 
    | MenhirCell1_clist1_expr_ of 's * ('s, 'r) _menhir_state * (AST.expr list)
  
  and ('s, 'r) _menhir_cell1_clist2_IDENTIFIER_ = 
    | MenhirCell1_clist2_IDENTIFIER_ of 's * ('s, 'r) _menhir_state * (string list)
  
  and ('s, 'r) _menhir_cell1_decl = 
    | MenhirCell1_decl of 's * ('s, 'r) _menhir_state * (AST.decl list)
  
  and ('s, 'r) _menhir_cell1_decl_item = 
    | MenhirCell1_decl_item of 's * ('s, 'r) _menhir_state * (AST.local_decl_item)
  
  and ('s, 'r) _menhir_cell1_direction = 
    | MenhirCell1_direction of 's * ('s, 'r) _menhir_state * (AST.for_direction)
  
  and ('s, 'r) _menhir_cell1_discard_or_field = 
    | MenhirCell1_discard_or_field of 's * ('s, 'r) _menhir_state * (Desugar.lhs_field option)
  
  and ('s, 'r) _menhir_cell1_discard_or_identifier = 
    | MenhirCell1_discard_or_identifier of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_discard_or_sliced_basic_lexpr = 
    | MenhirCell1_discard_or_sliced_basic_lexpr of 's * ('s, 'r) _menhir_state * (Desugar.lhs_access option)
  
  and ('s, 'r) _menhir_cell1_expr = 
    | MenhirCell1_expr of 's * ('s, 'r) _menhir_state * (AST.expr) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_expr_pattern = 
    | MenhirCell1_expr_pattern of 's * ('s, 'r) _menhir_state * (AST.expr) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_field_assign = 
    | MenhirCell1_field_assign of 's * ('s, 'r) _menhir_state * (string * AST.expr)
  
  and ('s, 'r) _menhir_cell1_func_args = 
    | MenhirCell1_func_args of 's * ('s, 'r) _menhir_state * (AST.typed_identifier list)
  
  and ('s, 'r) _menhir_cell1_global_let_or_constant = 
    | MenhirCell1_global_let_or_constant of 's * ('s, 'r) _menhir_state * (AST.global_decl_keyword) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ignored_or_identifier = 
    | MenhirCell1_ignored_or_identifier of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_int_constraint = 
    | MenhirCell1_int_constraint of 's * ('s, 'r) _menhir_state * (AST.int_constraint)
  
  and ('s, 'r) _menhir_cell1_lexpr = 
    | MenhirCell1_lexpr of 's * ('s, 'r) _menhir_state * (AST.lexpr) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_list1_case_alt_ = 
    | MenhirCell1_list1_case_alt_ of 's * ('s, 'r) _menhir_state * (AST.case_alt_desc AST.annotated list)
  
  and ('s, 'r) _menhir_cell1_list1_catcher_ = 
    | MenhirCell1_list1_catcher_ of 's * ('s, 'r) _menhir_state * (AST.catcher list)
  
  and ('s, 'r) _menhir_cell1_local_decl_keyword_non_var = 
    | MenhirCell1_local_decl_keyword_non_var of 's * ('s, 'r) _menhir_state * (AST.local_decl_keyword) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_loop_limit = 
    | MenhirCell1_loop_limit of 's * ('s, 'r) _menhir_state * (AST.expr option)
  
  and ('s, 'r) _menhir_cell1_maybe_empty_stmt_list = 
    | MenhirCell1_maybe_empty_stmt_list of 's * ('s, 'r) _menhir_state * (AST.stmt)
  
  and ('s, 'r) _menhir_cell1_opt_typed_identifier = 
    | MenhirCell1_opt_typed_identifier of 's * ('s, 'r) _menhir_state * (string * AST.ty option)
  
  and ('s, 'r) _menhir_cell1_option_as_ty_ = 
    | MenhirCell1_option_as_ty_ of 's * ('s, 'r) _menhir_state * (AST.ty option)
  
  and ('s, 'r) _menhir_cell1_params_opt = 
    | MenhirCell1_params_opt of 's * ('s, 'r) _menhir_state * ((string * AST.ty option) list)
  
  and ('s, 'r) _menhir_cell1_pattern = 
    | MenhirCell1_pattern of 's * ('s, 'r) _menhir_state * (AST.pattern) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_pattern_list = 
    | MenhirCell1_pattern_list of 's * ('s, 'r) _menhir_state * (AST.pattern)
  
  and ('s, 'r) _menhir_cell1_recurse_limit = 
    | MenhirCell1_recurse_limit of 's * ('s, 'r) _menhir_state * (AST.expr option)
  
  and ('s, 'r) _menhir_cell1_return_type = 
    | MenhirCell1_return_type of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_slice = 
    | MenhirCell1_slice of 's * ('s, 'r) _menhir_state * (AST.slice)
  
  and ('s, 'r) _menhir_cell1_slices = 
    | MenhirCell1_slices of 's * ('s, 'r) _menhir_state * (AST.slice list) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_stmt = 
    | MenhirCell1_stmt of 's * ('s, 'r) _menhir_state * (AST.stmt_desc AST.annotated) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_stmt_list = 
    | MenhirCell1_stmt_list of 's * ('s, 'r) _menhir_state * (AST.stmt) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ty = 
    | MenhirCell1_ty of 's * ('s, 'r) _menhir_state * (AST.ty) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ty_decl = 
    | MenhirCell1_ty_decl of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_typed_identifier = 
    | MenhirCell1_typed_identifier of 's * ('s, 'r) _menhir_state * (AST.field)
  
  and ('s, 'r) _menhir_cell1_ACCESSOR = 
    | MenhirCell1_ACCESSOR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_AND = 
    | MenhirCell1_AND of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ARBITRARY = 
    | MenhirCell1_ARBITRARY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ARRAY = 
    | MenhirCell1_ARRAY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ARROW = 
    | MenhirCell1_ARROW of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_AS = 
    | MenhirCell1_AS of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ASSERT = 
    | MenhirCell1_ASSERT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BAND = 
    | MenhirCell1_BAND of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BEGIN = 
    | MenhirCell1_BEGIN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BEQ = 
    | MenhirCell1_BEQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BITS = 
    | MenhirCell1_BITS of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BNOT = 
    | MenhirCell1_BNOT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BOR = 
    | MenhirCell1_BOR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CASE = 
    | MenhirCell1_CASE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLLECTION = 
    | MenhirCell1_COLLECTION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON = 
    | MenhirCell1_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_COLON_COLON = 
    | MenhirCell1_COLON_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_COMMA = 
    | MenhirCell1_COMMA of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CONFIG = 
    | MenhirCell1_CONFIG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_DEBUG = 
    | MenhirCell1_DEBUG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_DIV = 
    | MenhirCell1_DIV of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DIVRM = 
    | MenhirCell1_DIVRM of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DOT = 
    | MenhirCell1_DOT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ELSE = 
    | MenhirCell1_ELSE of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ELSIF = 
    | MenhirCell1_ELSIF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_END = 
    | MenhirCell0_END of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ENUMERATION = 
    | MenhirCell1_ENUMERATION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_EQ = 
    | MenhirCell1_EQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_EQ_OP = 
    | MenhirCell1_EQ_OP of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_EXCEPTION = 
    | MenhirCell1_EXCEPTION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FOR = 
    | MenhirCell1_FOR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FUNC = 
    | MenhirCell1_FUNC of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_FUNC = 
    | MenhirCell0_FUNC of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GEQ = 
    | MenhirCell1_GEQ of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GETTER = 
    | MenhirCell1_GETTER of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_GT = 
    | MenhirCell1_GT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_IDENTIFIER = 
    | MenhirCell1_IDENTIFIER of 's * ('s, 'r) _menhir_state * (
# 134 "asllib/Tokens.mly"
       (string)
# 2156 "asllib/Parser.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_IDENTIFIER = 
    | MenhirCell0_IDENTIFIER of 's * (
# 134 "asllib/Tokens.mly"
       (string)
# 2163 "asllib/Parser.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IF = 
    | MenhirCell1_IF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IMPDEF = 
    | MenhirCell1_IMPDEF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IMPL = 
    | MenhirCell1_IMPL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_IMPLEMENTATION = 
    | MenhirCell1_IMPLEMENTATION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IN = 
    | MenhirCell1_IN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_INTEGER = 
    | MenhirCell1_INTEGER of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACE = 
    | MenhirCell1_LBRACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LBRACE = 
    | MenhirCell0_LBRACE of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACKET = 
    | MenhirCell1_LBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LBRACKET = 
    | MenhirCell0_LBRACKET of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LEQ = 
    | MenhirCell1_LEQ of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LLBRACKET = 
    | MenhirCell1_LLBRACKET of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LOOPLIMIT = 
    | MenhirCell1_LOOPLIMIT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LPAR = 
    | MenhirCell1_LPAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LPAR = 
    | MenhirCell0_LPAR of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LT = 
    | MenhirCell1_LT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_MINUS = 
    | MenhirCell1_MINUS of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MOD = 
    | MenhirCell1_MOD of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_MUL = 
    | MenhirCell1_MUL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_NEQ = 
    | MenhirCell1_NEQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_NOT = 
    | MenhirCell1_NOT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_OF = 
    | MenhirCell1_OF of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_OR = 
    | MenhirCell1_OR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PLUS = 
    | MenhirCell1_PLUS of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PLUS_COLON = 
    | MenhirCell1_PLUS_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_POW = 
    | MenhirCell1_POW of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PRAGMA = 
    | MenhirCell1_PRAGMA of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PRINT = 
    | MenhirCell1_PRINT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PRINTLN = 
    | MenhirCell1_PRINTLN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RBRACE = 
    | MenhirCell1_RBRACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_RBRACE = 
    | MenhirCell0_RBRACE of 's * Lexing.position
  
  and 's _menhir_cell0_RBRACKET = 
    | MenhirCell0_RBRACKET of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RDIV = 
    | MenhirCell1_RDIV of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_RECORD = 
    | MenhirCell1_RECORD of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RECURSELIMIT = 
    | MenhirCell1_RECURSELIMIT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_REPEAT = 
    | MenhirCell1_REPEAT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RETURN = 
    | MenhirCell1_RETURN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RPAR = 
    | MenhirCell1_RPAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RRBRACKET = 
    | MenhirCell1_RRBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_SEMI_COLON = 
    | MenhirCell0_SEMI_COLON of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SETTER = 
    | MenhirCell1_SETTER of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SHL = 
    | MenhirCell1_SHL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SHR = 
    | MenhirCell1_SHR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SLICING = 
    | MenhirCell1_SLICING of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_STAR_COLON = 
    | MenhirCell1_STAR_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SUBTYPES = 
    | MenhirCell1_SUBTYPES of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_THEN = 
    | MenhirCell1_THEN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_THROW = 
    | MenhirCell1_THROW of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TRY = 
    | MenhirCell1_TRY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPE = 
    | MenhirCell1_TYPE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_VAR = 
    | MenhirCell1_VAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WHEN = 
    | MenhirCell1_WHEN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WHILE = 
    | MenhirCell1_WHILE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_XOR = 
    | MenhirCell1_XOR of 's * ('s, 'r) _menhir_state
  
  and _menhir_box_stmts = 
    | MenhirBox_stmts of (AST.stmt) [@@unboxed]
  
  and _menhir_box_spec = 
    | MenhirBox_spec of (AST.t) [@@unboxed]
  
  and _menhir_box_opn = 
    | MenhirBox_opn of (AST.t) [@@unboxed]
  
  let _menhir_action_003 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 getter setter ->
      let _6 =
        let (_2, _1) = (_2_inlined1, _1_inlined2) in
        ()
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 609 "asllib/Parser.mly"
    ( { getter; setter } )
# 2350 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_004 =
    fun _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined2_ _startpos__1_inlined2_ getter setter ->
      let _6 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2365 "asllib/Parser.ml"
        
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 609 "asllib/Parser.mly"
    ( { getter; setter } )
# 2375 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_005 =
    fun _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined1_ _startpos__1_inlined1_ getter setter ->
      let _6 =
        let _1 = _1_inlined2 in
        ()
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2394 "asllib/Parser.ml"
        
      in
      (
# 609 "asllib/Parser.mly"
    ( { getter; setter } )
# 2400 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_006 =
    fun _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter setter ->
      let _6 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2415 "asllib/Parser.ml"
        
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2428 "asllib/Parser.ml"
        
      in
      (
# 609 "asllib/Parser.mly"
    ( { getter; setter } )
# 2434 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_007 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 getter setter ->
      let _6 =
        let (_2, _1) = (_2_inlined1, _1_inlined2) in
        ()
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 612 "asllib/Parser.mly"
    ( { getter; setter } )
# 2450 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_008 =
    fun _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined2_ _startpos__1_inlined2_ getter setter ->
      let _6 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2465 "asllib/Parser.ml"
        
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 612 "asllib/Parser.mly"
    ( { getter; setter } )
# 2475 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_009 =
    fun _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined1_ _startpos__1_inlined1_ getter setter ->
      let _6 =
        let _1 = _1_inlined2 in
        ()
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2494 "asllib/Parser.ml"
        
      in
      (
# 612 "asllib/Parser.mly"
    ( { getter; setter } )
# 2500 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_010 =
    fun _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter setter ->
      let _6 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2515 "asllib/Parser.ml"
        
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2528 "asllib/Parser.ml"
        
      in
      (
# 612 "asllib/Parser.mly"
    ( { getter; setter } )
# 2534 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_011 =
    fun _1 _2 ->
      (_2 : (AST.ty))
  
  let _menhir_action_012 =
    fun _endpos_desc_ _startpos_desc_ desc fields ->
      let base =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2549 "asllib/Parser.ml"
        
      in
      (
# 424 "asllib/Parser.mly"
    ( lhs_access ~base ~index:None ~fields )
# 2555 "asllib/Parser.ml"
       : (Desugar.lhs_access))
  
  let _menhir_action_013 =
    fun _2 _4 _endpos_desc_ _startpos_desc_ desc fields idx ->
      let base =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2566 "asllib/Parser.ml"
        
      in
      (
# 426 "asllib/Parser.mly"
    ( lhs_access ~base ~index:(Some idx) ~fields )
# 2572 "asllib/Parser.ml"
       : (Desugar.lhs_access))
  
  let _menhir_action_014 =
    fun s x ->
      (
# 376 "asllib/Parser.mly"
                                              ( BitField_Simple (x, s)     )
# 2580 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_015 =
    fun bf s x ->
      (
# 377 "asllib/Parser.mly"
                                              ( BitField_Nested (x, s, bf) )
# 2588 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_016 =
    fun s ty x ->
      (
# 378 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 2596 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_017 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 2604 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_018 =
    fun () ->
      (
# 373 "asllib/Parser.mly"
                     ( [] )
# 2612 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_019 =
    fun _1 ->
      (_1 : (AST.bitfield list))
  
  let _menhir_action_020 =
    fun name x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 2624 "asllib/Parser.ml"
       in
      (
# 583 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 2629 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_021 =
    fun name x ->
      let args = 
# 580 "asllib/Parser.mly"
                     ( [] )
# 2637 "asllib/Parser.ml"
       in
      let params = 
# 205 "<standard.mly>"
    ( x )
# 2642 "asllib/Parser.ml"
       in
      (
# 585 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 2647 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_022 =
    fun name x x_inlined1 ->
      let args =
        let x = x_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 2657 "asllib/Parser.ml"
        
      in
      let params = 
# 205 "<standard.mly>"
    ( x )
# 2663 "asllib/Parser.ml"
       in
      (
# 585 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 2668 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_023 =
    fun _1 _4 _endpos_stmt_ _startpos__1_ pattern stmt ->
      let desc =
        let where = 
# 123 "<standard.mly>"
    ( None )
# 2677 "asllib/Parser.ml"
         in
        
# 496 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 2682 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_stmt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2691 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated))
  
  let _menhir_action_024 =
    fun _1 _1_inlined1 _2 _4 _endpos_stmt_ _startpos__1_ pattern stmt ->
      let desc =
        let where =
          let _1 = _1_inlined1 in
          let x = _2 in
          
# 126 "<standard.mly>"
    ( Some x )
# 2703 "asllib/Parser.ml"
          
        in
        
# 496 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 2709 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_stmt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2718 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated))
  
  let _menhir_action_025 =
    fun _1 _4 stmt_list ty ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 2726 "asllib/Parser.ml"
       in
      let _2_1 = _2 in
      ((_2_1, ty, stmt_list) : (AST.catcher))
  
  let _menhir_action_026 =
    fun _1 _4 stmt_list ty x ->
      let _2 =
        let x = 
# 196 "<standard.mly>"
    ( x )
# 2737 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 2742 "asllib/Parser.ml"
        
      in
      let _2_1 = _2 in
      ((_2_1, ty, stmt_list) : (AST.catcher))
  
  let _menhir_action_027 =
    fun () ->
      (
# 167 "asllib/Parser.mly"
                 ( [] )
# 2753 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_028 =
    fun _1 ->
      (_1 : (AST.expr list))
  
  let _menhir_action_029 =
    fun () ->
      (
# 167 "asllib/Parser.mly"
                 ( [] )
# 2765 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_030 =
    fun _1 ->
      (_1 : (AST.ty list))
  
  let _menhir_action_031 =
    fun () ->
      (
# 167 "asllib/Parser.mly"
                 ( [] )
# 2777 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_032 =
    fun _1 ->
      (_1 : (AST.typed_identifier list))
  
  let _menhir_action_033 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2789 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_034 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2797 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_035 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2805 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_036 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2813 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_037 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2821 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_038 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2829 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_039 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2837 "asllib/Parser.ml"
       : (Desugar.lhs_access option list))
  
  let _menhir_action_040 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2845 "asllib/Parser.ml"
       : (Desugar.lhs_access option list))
  
  let _menhir_action_041 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2853 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_042 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2861 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_043 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2869 "asllib/Parser.ml"
       : ((string * AST.expr) list))
  
  let _menhir_action_044 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2877 "asllib/Parser.ml"
       : ((string * AST.expr) list))
  
  let _menhir_action_045 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2885 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_046 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2893 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_047 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2901 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_048 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2909 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_049 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2917 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_050 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2925 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_051 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2933 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_052 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2941 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_053 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2949 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_054 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2957 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_055 =
    fun x ->
      (
# 163 "asllib/Parser.mly"
         ( [ x ] )
# 2965 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_056 =
    fun _2 h t ->
      (
# 164 "asllib/Parser.mly"
                             ( h :: t )
# 2973 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_057 =
    fun _2 li x ->
      (
# 170 "asllib/Parser.mly"
                                           ( x :: li )
# 2981 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_058 =
    fun _2 li x ->
      (
# 170 "asllib/Parser.mly"
                                           ( x :: li )
# 2989 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_059 =
    fun _2 li x ->
      (
# 170 "asllib/Parser.mly"
                                           ( x :: li )
# 2997 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_060 =
    fun _2 li x ->
      (
# 170 "asllib/Parser.mly"
                                           ( x :: li )
# 3005 "asllib/Parser.ml"
       : (Desugar.lhs_access option list))
  
  let _menhir_action_061 =
    fun _2 li x ->
      (
# 170 "asllib/Parser.mly"
                                           ( x :: li )
# 3013 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_062 =
    fun _2 li x ->
      (
# 170 "asllib/Parser.mly"
                                           ( x :: li )
# 3021 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_063 =
    fun x ->
      let cs = 
# 205 "<standard.mly>"
    ( x )
# 3029 "asllib/Parser.ml"
       in
      (
# 299 "asllib/Parser.mly"
                                       ( WellConstrained (cs, Precision_Full) )
# 3034 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_064 =
    fun x ->
      let _1 = 
# 205 "<standard.mly>"
    ( x )
# 3042 "asllib/Parser.ml"
       in
      (
# 300 "asllib/Parser.mly"
                   ( PendingConstrained )
# 3047 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_065 =
    fun _1 ->
      (_1 : (AST.constraint_kind))
  
  let _menhir_action_066 =
    fun () ->
      (
# 297 "asllib/Parser.mly"
                                             ( UnConstrained )
# 3059 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_067 =
    fun _1_inlined1 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _2 = _2_inlined1 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3075 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3081 "asllib/Parser.ml"
           in
          
# 618 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3098 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__2_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3107 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3113 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_068 =
    fun _1_inlined1 _2 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3131 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3137 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3143 "asllib/Parser.ml"
           in
          
# 618 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3160 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__2_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3169 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3175 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_069 =
    fun _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_2, _1_inlined1) = (_2_inlined1, _1_inlined2) in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3191 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 603 "asllib/Parser.mly"
              ( Impdef )
# 3198 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3203 "asllib/Parser.ml"
            
          in
          
# 618 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3221 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3230 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3236 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_070 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3255 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3261 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 603 "asllib/Parser.mly"
              ( Impdef )
# 3268 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3273 "asllib/Parser.ml"
            
          in
          
# 618 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3291 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3300 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3306 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_071 =
    fun _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_2, _1_inlined1) = (_2_inlined1, _1_inlined2) in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3322 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 604 "asllib/Parser.mly"
                      ( Implementation )
# 3329 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3334 "asllib/Parser.ml"
            
          in
          
# 618 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3352 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3361 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3367 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_072 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3386 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3392 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 604 "asllib/Parser.mly"
                      ( Implementation )
# 3399 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3404 "asllib/Parser.ml"
            
          in
          
# 618 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            override;
            builtin = false;
          }
        )
# 3422 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3431 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3437 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_073 =
    fun _1_inlined1 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _2 = _2_inlined1 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3453 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3459 "asllib/Parser.ml"
           in
          
# 634 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3476 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__2_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3485 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3491 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_074 =
    fun _1_inlined1 _2 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3509 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3515 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3521 "asllib/Parser.ml"
           in
          
# 634 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3538 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__2_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3547 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3553 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_075 =
    fun _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_2, _1_inlined1) = (_2_inlined1, _1_inlined2) in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3569 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 603 "asllib/Parser.mly"
              ( Impdef )
# 3576 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3581 "asllib/Parser.ml"
            
          in
          
# 634 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3599 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3608 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3614 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_076 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3633 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3639 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 603 "asllib/Parser.mly"
              ( Impdef )
# 3646 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3651 "asllib/Parser.ml"
            
          in
          
# 634 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3669 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3678 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3684 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_077 =
    fun _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_2, _1_inlined1) = (_2_inlined1, _1_inlined2) in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3700 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 604 "asllib/Parser.mly"
                      ( Implementation )
# 3707 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3712 "asllib/Parser.ml"
            
          in
          
# 634 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3730 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3739 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3745 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_078 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3764 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3770 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 604 "asllib/Parser.mly"
                      ( Implementation )
# 3777 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3782 "asllib/Parser.ml"
            
          in
          
# 634 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override;
            builtin = false;
          }
        )
# 3800 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3809 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3815 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_079 =
    fun _1 _3 _endpos__2_ _startpos__1_ subtype_opt t x ->
      let d =
        let desc =
          let x = 
# 650 "asllib/Parser.mly"
                                                            D_TypeDecl            
# 3825 "asllib/Parser.ml"
           (x, t, subtype_opt) in
          
# 196 "<standard.mly>"
    ( x )
# 3830 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3839 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3845 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_080 =
    fun _1 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc x ->
      let d =
        let desc =
          let x =
            let s =
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3859 "asllib/Parser.ml"
              
            in
            
# 653 "asllib/Parser.mly"
                                                            make_ty_decl_subtype  
# 3865 "asllib/Parser.ml"
             (x, s)
          in
          
# 196 "<standard.mly>"
    ( x )
# 3871 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3880 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3886 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_081 =
    fun _4 _endpos__2_ _startpos_keyword_ keyword name ty x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 149 "asllib/Parser.mly"
                        Some 
# 3897 "asllib/Parser.ml"
             x in
            
# 658 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 3902 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 3908 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_keyword_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3917 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3923 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_082 =
    fun _1 _4 _endpos__2_ _startpos__1_ name ty x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 149 "asllib/Parser.mly"
                        Some 
# 3934 "asllib/Parser.ml"
             x in
            
# 661 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Config; name; ty=Some ty; initial_value } )
# 3939 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 3945 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3954 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3960 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_083 =
    fun _1 _4 _endpos__2_ _startpos__1_ name ty x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 149 "asllib/Parser.mly"
                        Some 
# 3971 "asllib/Parser.ml"
             x in
            
# 664 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value } )
# 3976 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 3982 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3991 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 3997 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_084 =
    fun _1 _endpos__2_ _startpos__1_ name x ->
      let d =
        let desc =
          let x =
            let ty = 
# 149 "asllib/Parser.mly"
                        Some 
# 4008 "asllib/Parser.ml"
             x in
            
# 668 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value=None})
# 4013 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 4019 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4028 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 4034 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_085 =
    fun _1 _endpos__2_ _startpos__1_ e x ->
      let d =
        let desc =
          let x = 
# 671 "asllib/Parser.mly"
                                                D_Pragma  
# 4044 "asllib/Parser.ml"
           (x, e) in
          
# 196 "<standard.mly>"
    ( x )
# 4049 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4058 "asllib/Parser.ml"
        
      in
      (
# 674 "asllib/Parser.mly"
     ( [d] )
# 4064 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_086 =
    fun _1 _1_inlined1 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let _2 = _2_inlined1 in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 680 "asllib/Parser.mly"
  ( accessors )
# 4078 "asllib/Parser.ml"
        
      in
      let override = 
# 123 "<standard.mly>"
    ( None )
# 4084 "asllib/Parser.ml"
       in
      (
# 677 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4089 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_087 =
    fun _1 _1_inlined1 _2 _6 _endpos__1_inlined1_ _startpos__1_inlined1_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4105 "asllib/Parser.ml"
          
        in
        
# 680 "asllib/Parser.mly"
  ( accessors )
# 4111 "asllib/Parser.ml"
        
      in
      let override = 
# 123 "<standard.mly>"
    ( None )
# 4117 "asllib/Parser.ml"
       in
      (
# 677 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4122 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_088 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_2, _1_inlined1, _1) = (_2_inlined1, _1_inlined2, _1_inlined1) in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 680 "asllib/Parser.mly"
  ( accessors )
# 4136 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 603 "asllib/Parser.mly"
              ( Impdef )
# 4143 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 4148 "asllib/Parser.ml"
        
      in
      (
# 677 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4154 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_089 =
    fun _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2, _1_inlined1) in
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4171 "asllib/Parser.ml"
          
        in
        
# 680 "asllib/Parser.mly"
  ( accessors )
# 4177 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 603 "asllib/Parser.mly"
              ( Impdef )
# 4184 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 4189 "asllib/Parser.ml"
        
      in
      (
# 677 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4195 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_090 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_2, _1_inlined1, _1) = (_2_inlined1, _1_inlined2, _1_inlined1) in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 680 "asllib/Parser.mly"
  ( accessors )
# 4209 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 604 "asllib/Parser.mly"
                      ( Implementation )
# 4216 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 4221 "asllib/Parser.ml"
        
      in
      (
# 677 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4227 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_091 =
    fun _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2, _1_inlined1) in
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4244 "asllib/Parser.ml"
          
        in
        
# 680 "asllib/Parser.mly"
  ( accessors )
# 4250 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 604 "asllib/Parser.mly"
                      ( Implementation )
# 4257 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 4262 "asllib/Parser.ml"
        
      in
      (
# 677 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 4268 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_092 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _startpos = _startpos__1_ in
      (
# 464 "asllib/Parser.mly"
                                       (
      if Config.allow_storage_discards then LDI_Var (local_ignored ())
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
    )
# 4281 "asllib/Parser.ml"
       : (AST.local_decl_item))
  
  let _menhir_action_093 =
    fun _1 ->
      let _1_1 = _1 in
      (
# 468 "asllib/Parser.mly"
                                         LDI_Var  
# 4290 "asllib/Parser.ml"
       _1_1 : (AST.local_decl_item))
  
  let _menhir_action_094 =
    fun _endpos__3_ _startpos__1_ x ->
      let vs = 
# 205 "<standard.mly>"
    ( x )
# 4298 "asllib/Parser.ml"
       in
      let (_endpos_vs_, _startpos_vs_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_vs_ in
      let _startpos = _startpos_vs_ in
      (
# 469 "asllib/Parser.mly"
                                       (
      if List.for_all is_local_ignored vs && not Config.allow_storage_discards then
        Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
      else LDI_Tuple vs
    )
# 4310 "asllib/Parser.ml"
       : (AST.local_decl_item))
  
  let _menhir_action_095 =
    fun _1 ->
      (
# 491 "asllib/Parser.mly"
                       ( AST.Up )
# 4318 "asllib/Parser.ml"
       : (AST.for_direction))
  
  let _menhir_action_096 =
    fun _1 ->
      (
# 491 "asllib/Parser.mly"
                                            ( AST.Down )
# 4326 "asllib/Parser.ml"
       : (AST.for_direction))
  
  let _menhir_action_097 =
    fun _1 ->
      (
# 441 "asllib/Parser.mly"
                             ( None )
# 4334 "asllib/Parser.ml"
       : (Desugar.lhs_field option))
  
  let _menhir_action_098 =
    fun _endpos_desc_ _startpos_desc_ desc ->
      let _1 =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4345 "asllib/Parser.ml"
        
      in
      let _1_1 = _1 in
      (
# 442 "asllib/Parser.mly"
                               Some  
# 4352 "asllib/Parser.ml"
       _1_1 : (Desugar.lhs_field option))
  
  let _menhir_action_099 =
    fun _1 ->
      (
# 460 "asllib/Parser.mly"
                   ( local_ignored () )
# 4360 "asllib/Parser.ml"
       : (string))
  
  let _menhir_action_100 =
    fun _1 ->
      (_1 : (string))
  
  let _menhir_action_101 =
    fun _1 ->
      (
# 437 "asllib/Parser.mly"
                          ( None )
# 4372 "asllib/Parser.ml"
       : (Desugar.lhs_access option))
  
  let _menhir_action_102 =
    fun sliced_basic_lexpr ->
      (
# 438 "asllib/Parser.mly"
                            Some  
# 4380 "asllib/Parser.ml"
       sliced_basic_lexpr : (Desugar.lhs_access option))
  
  let _menhir_action_103 =
    fun _1 _2 ->
      (_2 : (AST.expr))
  
  let _menhir_action_104 =
    fun _1 _3 _endpos_e2_ _startpos__1_ c e1 e2 ->
      let desc =
        let _endpos = _endpos_e2_ in
        let _startpos = _startpos__1_ in
        
# 253 "asllib/Parser.mly"
                                                                          (
      if Config.allow_expression_elsif then E_Cond (c, e1, e2)
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Expression-level 'elsif'."
    )
# 4398 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4407 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_105 =
    fun _2 _3 name ->
      let args = 
# 580 "asllib/Parser.mly"
                     ( [] )
# 4415 "asllib/Parser.ml"
       in
      (
# 588 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 4420 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_106 =
    fun _2 _3 name x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 4428 "asllib/Parser.ml"
       in
      (
# 588 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 4433 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_107 =
    fun _2 _3 _5 name params ->
      let args = 
# 580 "asllib/Parser.mly"
                     ( [] )
# 4441 "asllib/Parser.ml"
       in
      (
# 590 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 4446 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_108 =
    fun _2 _3 _5 name params x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 4454 "asllib/Parser.ml"
       in
      (
# 590 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 4459 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_109 =
    fun _endpos_value_ _startpos_value_ value ->
      let desc = 
# 262 "asllib/Parser.mly"
                                                                    E_Literal             
# 4467 "asllib/Parser.ml"
       value in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_value_, _startpos_value_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4475 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_110 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 263 "asllib/Parser.mly"
                                                                    E_Var                 
# 4485 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4494 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_111 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 218 "asllib/Parser.mly"
                  ( `AND    )
# 4503 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4508 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4517 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_112 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 219 "asllib/Parser.mly"
                  ( `BAND   )
# 4526 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4531 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4540 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_113 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 220 "asllib/Parser.mly"
                  ( `BOR    )
# 4549 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4554 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4563 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_114 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 221 "asllib/Parser.mly"
                  ( `BEQ    )
# 4572 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4577 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4586 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_115 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 222 "asllib/Parser.mly"
                  ( `DIV    )
# 4595 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4600 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4609 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_116 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 223 "asllib/Parser.mly"
                  ( `DIVRM  )
# 4618 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4623 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4632 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_117 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 224 "asllib/Parser.mly"
                  ( `XOR    )
# 4641 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4646 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4655 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_118 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 225 "asllib/Parser.mly"
                  ( `EQ_OP  )
# 4664 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4669 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4678 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_119 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 226 "asllib/Parser.mly"
                  ( `NEQ    )
# 4687 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4692 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4701 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_120 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 227 "asllib/Parser.mly"
                  ( `GT     )
# 4710 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4715 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4724 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_121 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 228 "asllib/Parser.mly"
                  ( `GEQ    )
# 4733 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4738 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4747 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_122 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 229 "asllib/Parser.mly"
                  ( `IMPL   )
# 4756 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4761 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4770 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_123 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 230 "asllib/Parser.mly"
                  ( `LT     )
# 4779 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4784 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4793 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_124 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 231 "asllib/Parser.mly"
                  ( `LEQ    )
# 4802 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4807 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4816 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_125 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 232 "asllib/Parser.mly"
                  ( `PLUS   )
# 4825 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4830 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4839 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_126 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 233 "asllib/Parser.mly"
                  ( `MINUS  )
# 4848 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4853 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4862 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_127 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 234 "asllib/Parser.mly"
                  ( `MOD    )
# 4871 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4876 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4885 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_128 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 235 "asllib/Parser.mly"
                  ( `MUL    )
# 4894 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4899 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4908 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_129 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 236 "asllib/Parser.mly"
                  ( `OR     )
# 4917 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4922 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4931 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_130 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 237 "asllib/Parser.mly"
                  ( `RDIV   )
# 4940 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4945 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4954 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_131 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 238 "asllib/Parser.mly"
                  ( `SHL    )
# 4963 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4968 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4977 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_132 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 239 "asllib/Parser.mly"
                  ( `SHR    )
# 4986 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 4991 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5000 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_133 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 240 "asllib/Parser.mly"
                  ( `POW    )
# 5009 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 5014 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5023 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_134 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 241 "asllib/Parser.mly"
                  ( `CONCAT )
# 5032 "asllib/Parser.ml"
         in
        
# 264 "asllib/Parser.mly"
                                                                e_binop               
# 5037 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5046 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_135 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 213 "asllib/Parser.mly"
            ( BNOT )
# 5055 "asllib/Parser.ml"
         in
        
# 265 "asllib/Parser.mly"
                                                                    E_Unop                
# 5060 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5069 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_136 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 214 "asllib/Parser.mly"
            ( NEG )
# 5078 "asllib/Parser.ml"
         in
        
# 265 "asllib/Parser.mly"
                                                                    E_Unop                
# 5083 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5092 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_137 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 215 "asllib/Parser.mly"
            ( NOT )
# 5101 "asllib/Parser.ml"
         in
        
# 265 "asllib/Parser.mly"
                                                                    E_Unop                
# 5106 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5115 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_138 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else ->
      let desc = 
# 266 "asllib/Parser.mly"
                                                                    E_Cond                
# 5123 "asllib/Parser.ml"
       (e1, e2, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5131 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_139 =
    fun _endpos_call_ _startpos_call_ call ->
      let desc = 
# 267 "asllib/Parser.mly"
                                                                    e_call                
# 5139 "asllib/Parser.ml"
       call in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_call_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5147 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_140 =
    fun _endpos_slices_ _startpos_e_ e slices ->
      let desc = 
# 268 "asllib/Parser.mly"
                                                                E_Slice               
# 5155 "asllib/Parser.ml"
       (e, slices) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_slices_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5163 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_141 =
    fun _2 _4 _endpos__4_ _startpos_e1_ e1 e2 ->
      let desc = 
# 269 "asllib/Parser.mly"
                                                                E_GetArray            
# 5171 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__4_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5179 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_142 =
    fun _2 _endpos_x_ _startpos_e_ e x ->
      let desc = 
# 270 "asllib/Parser.mly"
                                                                E_GetField            
# 5187 "asllib/Parser.ml"
       (e, x) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_x_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5195 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_143 =
    fun _2 _endpos__3_ _startpos_e_ e x ->
      let desc =
        let fs = 
# 205 "<standard.mly>"
    ( x )
# 5204 "asllib/Parser.ml"
         in
        
# 271 "asllib/Parser.mly"
                                                                E_GetFields           
# 5209 "asllib/Parser.ml"
         (e, fs)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5218 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_144 =
    fun _2 _endpos_ty_ _startpos_expr_ expr ty ->
      let desc = 
# 273 "asllib/Parser.mly"
                                                                E_ATC                 
# 5226 "asllib/Parser.ml"
       (expr, ty) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5234 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_145 =
    fun _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_ constraint_kind expr ->
      let desc =
        let implicit_t_int =
          let desc = 
# 412 "asllib/Parser.mly"
                                                       T_Int 
# 5244 "asllib/Parser.ml"
           constraint_kind in
          let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_constraint_kind_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5252 "asllib/Parser.ml"
          
        in
        
# 274 "asllib/Parser.mly"
                                                                E_ATC                 
# 5258 "asllib/Parser.ml"
         (expr, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5267 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_146 =
    fun _2 _endpos_pattern_set_ _startpos_expr_ expr pattern_set ->
      let desc = 
# 276 "asllib/Parser.mly"
                                                                E_Pattern             
# 5275 "asllib/Parser.ml"
       (expr, pattern_set) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_pattern_set_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5283 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_147 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_ expr ->
      let desc =
        let pattern_mask =
          let desc =
            let _1_1 = _1 in
            
# 337 "asllib/Parser.mly"
                                            Pattern_Mask  
# 5295 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5304 "asllib/Parser.ml"
          
        in
        
# 277 "asllib/Parser.mly"
                                                                E_Pattern             
# 5310 "asllib/Parser.ml"
         (expr, pattern_mask)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5319 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_148 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e ->
      let desc =
        let p =
          let desc =
            let _1_1 = _1 in
            
# 337 "asllib/Parser.mly"
                                            Pattern_Mask  
# 5331 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5340 "asllib/Parser.ml"
          
        in
        
# 278 "asllib/Parser.mly"
                                                              ( E_Pattern (e, Pattern_Not (p) |> add_pos_from p) )
# 5346 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5355 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_149 =
    fun _1 _2 _endpos_ty_ _startpos__1_ ty ->
      let desc = 
# 279 "asllib/Parser.mly"
                                                                E_Arbitrary         
# 5363 "asllib/Parser.ml"
       ty in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5371 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_150 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 5380 "asllib/Parser.ml"
         in
        
# 280 "asllib/Parser.mly"
                                                              ( E_Tuple [ e ]        )
# 5385 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5394 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_151 =
    fun _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5406 "asllib/Parser.ml"
          
        in
        
# 282 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), []) )
# 5412 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__4_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5421 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_152 =
    fun _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let fields = 
# 205 "<standard.mly>"
    ( x )
# 5430 "asllib/Parser.ml"
         in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5438 "asllib/Parser.ml"
          
        in
        
# 284 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 5444 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5453 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_153 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let _1 = 
# 205 "<standard.mly>"
    ( x )
# 5462 "asllib/Parser.ml"
         in
        let _1_1 = _1 in
        
# 286 "asllib/Parser.mly"
                                                                    E_Tuple               
# 5468 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5477 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_154 =
    fun _endpos_value_ _startpos_value_ value ->
      let desc = 
# 311 "asllib/Parser.mly"
                                                                    E_Literal             
# 5485 "asllib/Parser.ml"
       value in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_value_, _startpos_value_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5493 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_155 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 312 "asllib/Parser.mly"
                                                                    E_Var                 
# 5503 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5512 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_156 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 218 "asllib/Parser.mly"
                  ( `AND    )
# 5521 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5526 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5535 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_157 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 219 "asllib/Parser.mly"
                  ( `BAND   )
# 5544 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5549 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5558 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_158 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 220 "asllib/Parser.mly"
                  ( `BOR    )
# 5567 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5572 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5581 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_159 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 221 "asllib/Parser.mly"
                  ( `BEQ    )
# 5590 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5595 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5604 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_160 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 222 "asllib/Parser.mly"
                  ( `DIV    )
# 5613 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5618 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5627 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_161 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 223 "asllib/Parser.mly"
                  ( `DIVRM  )
# 5636 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5641 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5650 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_162 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 224 "asllib/Parser.mly"
                  ( `XOR    )
# 5659 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5664 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5673 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_163 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 225 "asllib/Parser.mly"
                  ( `EQ_OP  )
# 5682 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5687 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5696 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_164 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 226 "asllib/Parser.mly"
                  ( `NEQ    )
# 5705 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5710 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5719 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_165 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 227 "asllib/Parser.mly"
                  ( `GT     )
# 5728 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5733 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5742 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_166 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 228 "asllib/Parser.mly"
                  ( `GEQ    )
# 5751 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5756 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5765 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_167 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 229 "asllib/Parser.mly"
                  ( `IMPL   )
# 5774 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5779 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5788 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_168 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 230 "asllib/Parser.mly"
                  ( `LT     )
# 5797 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5802 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5811 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_169 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 231 "asllib/Parser.mly"
                  ( `LEQ    )
# 5820 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5825 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5834 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_170 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 232 "asllib/Parser.mly"
                  ( `PLUS   )
# 5843 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5848 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5857 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_171 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 233 "asllib/Parser.mly"
                  ( `MINUS  )
# 5866 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5871 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5880 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_172 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 234 "asllib/Parser.mly"
                  ( `MOD    )
# 5889 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5894 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5903 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_173 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 235 "asllib/Parser.mly"
                  ( `MUL    )
# 5912 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5917 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5926 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_174 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 236 "asllib/Parser.mly"
                  ( `OR     )
# 5935 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5940 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5949 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_175 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 237 "asllib/Parser.mly"
                  ( `RDIV   )
# 5958 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5963 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5972 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_176 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 238 "asllib/Parser.mly"
                  ( `SHL    )
# 5981 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 5986 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5995 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_177 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 239 "asllib/Parser.mly"
                  ( `SHR    )
# 6004 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 6009 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6018 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_178 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 240 "asllib/Parser.mly"
                  ( `POW    )
# 6027 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 6032 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6041 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_179 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 241 "asllib/Parser.mly"
                  ( `CONCAT )
# 6050 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                        e_binop               
# 6055 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6064 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_180 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 213 "asllib/Parser.mly"
            ( BNOT )
# 6073 "asllib/Parser.ml"
         in
        
# 314 "asllib/Parser.mly"
                                                                    E_Unop                
# 6078 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6087 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_181 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 214 "asllib/Parser.mly"
            ( NEG )
# 6096 "asllib/Parser.ml"
         in
        
# 314 "asllib/Parser.mly"
                                                                    E_Unop                
# 6101 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6110 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_182 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 215 "asllib/Parser.mly"
            ( NOT )
# 6119 "asllib/Parser.ml"
         in
        
# 314 "asllib/Parser.mly"
                                                                    E_Unop                
# 6124 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6133 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_183 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else ->
      let desc = 
# 315 "asllib/Parser.mly"
                                                                    E_Cond                
# 6141 "asllib/Parser.ml"
       (e1, e2, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6149 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_184 =
    fun _endpos_call_ _startpos_call_ call ->
      let desc = 
# 316 "asllib/Parser.mly"
                                                                    e_call                
# 6157 "asllib/Parser.ml"
       call in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_call_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6165 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_185 =
    fun _endpos_slices_ _startpos_e_ e slices ->
      let desc = 
# 317 "asllib/Parser.mly"
                                                                        E_Slice               
# 6173 "asllib/Parser.ml"
       (e, slices) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_slices_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6181 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_186 =
    fun _2 _4 _endpos__4_ _startpos_e1_ e1 e2 ->
      let desc = 
# 318 "asllib/Parser.mly"
                                                                        E_GetArray            
# 6189 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__4_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6197 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_187 =
    fun _2 _endpos_x_ _startpos_e_ e x ->
      let desc = 
# 319 "asllib/Parser.mly"
                                                                        E_GetField            
# 6205 "asllib/Parser.ml"
       (e, x) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_x_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6213 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_188 =
    fun _2 _endpos__3_ _startpos_e_ e x ->
      let desc =
        let fs = 
# 205 "<standard.mly>"
    ( x )
# 6222 "asllib/Parser.ml"
         in
        
# 320 "asllib/Parser.mly"
                                                                        E_GetFields           
# 6227 "asllib/Parser.ml"
         (e, fs)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6236 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_189 =
    fun _2 _endpos_ty_ _startpos_expr_pattern_ expr_pattern ty ->
      let desc = 
# 322 "asllib/Parser.mly"
                                                                        E_ATC                 
# 6244 "asllib/Parser.ml"
       (expr_pattern, ty) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6252 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_190 =
    fun _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_pattern_ constraint_kind expr_pattern ->
      let desc =
        let implicit_t_int =
          let desc = 
# 412 "asllib/Parser.mly"
                                                       T_Int 
# 6262 "asllib/Parser.ml"
           constraint_kind in
          let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_constraint_kind_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6270 "asllib/Parser.ml"
          
        in
        
# 323 "asllib/Parser.mly"
                                                                        E_ATC                 
# 6276 "asllib/Parser.ml"
         (expr_pattern, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6285 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_191 =
    fun _2 _endpos_pattern_set_ _startpos_expr_pattern_ expr_pattern pattern_set ->
      let desc = 
# 325 "asllib/Parser.mly"
                                                                        E_Pattern             
# 6293 "asllib/Parser.ml"
       (expr_pattern, pattern_set) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_pattern_set_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6301 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_192 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_pattern_ expr_pattern ->
      let desc =
        let pattern_mask =
          let desc =
            let _1_1 = _1 in
            
# 337 "asllib/Parser.mly"
                                            Pattern_Mask  
# 6313 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6322 "asllib/Parser.ml"
          
        in
        
# 326 "asllib/Parser.mly"
                                                                        E_Pattern             
# 6328 "asllib/Parser.ml"
         (expr_pattern, pattern_mask)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6337 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_193 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e ->
      let desc =
        let p =
          let desc =
            let _1_1 = _1 in
            
# 337 "asllib/Parser.mly"
                                            Pattern_Mask  
# 6349 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6358 "asllib/Parser.ml"
          
        in
        
# 327 "asllib/Parser.mly"
                                                                      ( E_Pattern (e, Pattern_Not (p) |> add_pos_from p) )
# 6364 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6373 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_194 =
    fun _1 _2 _endpos_ty_ _startpos__1_ ty ->
      let desc = 
# 329 "asllib/Parser.mly"
                                                                        E_Arbitrary         
# 6381 "asllib/Parser.ml"
       ty in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6389 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_195 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 6398 "asllib/Parser.ml"
         in
        
# 330 "asllib/Parser.mly"
                                                                      ( E_Tuple [ e ]        )
# 6403 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6412 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_196 =
    fun _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6424 "asllib/Parser.ml"
          
        in
        
# 332 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), []) )
# 6430 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__4_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6439 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_197 =
    fun _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let fields = 
# 205 "<standard.mly>"
    ( x )
# 6448 "asllib/Parser.ml"
         in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6456 "asllib/Parser.ml"
          
        in
        
# 334 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 6462 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6471 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_198 =
    fun x y ->
      (
# 180 "<standard.mly>"
    ( (x, y) )
# 6479 "asllib/Parser.ml"
       : (string * AST.expr))
  
  let _menhir_action_199 =
    fun x ->
      let _1 = 
# 205 "<standard.mly>"
    ( x )
# 6487 "asllib/Parser.ml"
       in
      (
# 359 "asllib/Parser.mly"
                   ( [] )
# 6492 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_200 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 6500 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_201 =
    fun () ->
      (
# 361 "asllib/Parser.mly"
                  ( [] )
# 6508 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_202 =
    fun _1 ->
      (_1 : (AST.field list))
  
  let _menhir_action_203 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 6520 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_204 =
    fun _1 ->
      (
# 486 "asllib/Parser.mly"
                ( GDK_Let      )
# 6528 "asllib/Parser.ml"
       : (AST.global_decl_keyword))
  
  let _menhir_action_205 =
    fun _1 ->
      (
# 487 "asllib/Parser.mly"
                ( GDK_Constant )
# 6536 "asllib/Parser.ml"
       : (AST.global_decl_keyword))
  
  let _menhir_action_206 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _startpos = _startpos__1_ in
      (
# 596 "asllib/Parser.mly"
                            (
      if Config.allow_storage_discards then global_ignored ()
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
    )
# 6549 "asllib/Parser.ml"
       : (string))
  
  let _menhir_action_207 =
    fun _1 ->
      (_1 : (string))
  
  let _menhir_action_208 =
    fun expr ->
      (
# 303 "asllib/Parser.mly"
                                  Constraint_Exact  
# 6561 "asllib/Parser.ml"
       expr : (AST.int_constraint))
  
  let _menhir_action_209 =
    fun _2 e1 e2 ->
      (
# 304 "asllib/Parser.mly"
                                  Constraint_Range  
# 6569 "asllib/Parser.ml"
       (e1, e2) : (AST.int_constraint))
  
  let _menhir_action_210 =
    fun sliced_basic_lexpr ->
      (
# 445 "asllib/Parser.mly"
                            desugar_lhs_access  
# 6577 "asllib/Parser.ml"
       sliced_basic_lexpr : (AST.lexpr))
  
  let _menhir_action_211 =
    fun _endpos__3_ _startpos__1_ x ->
      let _1 =
        let desc = 
# 205 "<standard.mly>"
    ( x )
# 6586 "asllib/Parser.ml"
         in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6594 "asllib/Parser.ml"
        
      in
      let _1_1 = _1 in
      (
# 446 "asllib/Parser.mly"
                                                          desugar_lhs_tuple  
# 6601 "asllib/Parser.ml"
       _1_1 : (AST.lexpr))
  
  let _menhir_action_212 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 448 "asllib/Parser.mly"
             ( LE_Discard )
# 6609 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6617 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_213 =
    fun _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let flds = 
# 205 "<standard.mly>"
    ( x )
# 6626 "asllib/Parser.ml"
         in
        let x =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6634 "asllib/Parser.ml"
          
        in
        
# 450 "asllib/Parser.mly"
      ( LE_SetFields (le_var x, flds, []) )
# 6640 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6649 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_214 =
    fun _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let flds = 
# 205 "<standard.mly>"
    ( x )
# 6658 "asllib/Parser.ml"
         in
        let x =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6666 "asllib/Parser.ml"
          
        in
        
# 452 "asllib/Parser.mly"
      ( desugar_lhs_fields_tuple x flds )
# 6672 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6681 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_215 =
    fun () ->
      (
# 216 "<standard.mly>"
    ( [] )
# 6689 "asllib/Parser.ml"
       : (AST.decl list list))
  
  let _menhir_action_216 =
    fun x xs ->
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 6697 "asllib/Parser.ml"
       : (AST.decl list list))
  
  let _menhir_action_217 =
    fun x ->
      (
# 188 "asllib/Parser.mly"
         ( [ x ] )
# 6705 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated list))
  
  let _menhir_action_218 =
    fun l x ->
      (
# 189 "asllib/Parser.mly"
                     ( x :: l )
# 6713 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated list))
  
  let _menhir_action_219 =
    fun x ->
      (
# 188 "asllib/Parser.mly"
         ( [ x ] )
# 6721 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_220 =
    fun l x ->
      (
# 189 "asllib/Parser.mly"
                     ( x :: l )
# 6729 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_221 =
    fun x ->
      (
# 188 "asllib/Parser.mly"
         ( [ x ] )
# 6737 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_222 =
    fun l x ->
      (
# 189 "asllib/Parser.mly"
                     ( x :: l )
# 6745 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_223 =
    fun _1 ->
      (
# 479 "asllib/Parser.mly"
                ( LDK_Let       )
# 6753 "asllib/Parser.ml"
       : (AST.local_decl_keyword))
  
  let _menhir_action_224 =
    fun _1 ->
      (
# 480 "asllib/Parser.mly"
                ( LDK_Constant  )
# 6761 "asllib/Parser.ml"
       : (AST.local_decl_keyword))
  
  let _menhir_action_225 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 6769 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_226 =
    fun _1 _2 ->
      let x = _2 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 6778 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_227 =
    fun _1 ->
      (_1 : (AST.stmt))
  
  let _menhir_action_228 =
    fun _endpos__0_ ->
      let desc = 
# 592 "asllib/Parser.mly"
                                                   ( S_Pass )
# 6790 "asllib/Parser.ml"
       in
      let _endpos_desc_ = _endpos__0_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _endpos in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6798 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_229 =
    fun () ->
      (
# 429 "asllib/Parser.mly"
    ( [] )
# 6806 "asllib/Parser.ml"
       : (Desugar.lhs_field list))
  
  let _menhir_action_230 =
    fun _1 _endpos_desc_ _startpos_desc_ desc t ->
      let h =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6817 "asllib/Parser.ml"
        
      in
      (
# 430 "asllib/Parser.mly"
                                                   ( h :: t )
# 6823 "asllib/Parser.ml"
       : (Desugar.lhs_field list))
  
  let _menhir_action_231 =
    fun _2 body ->
      (
# 687 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            override = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 6847 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_232 =
    fun x ->
      let y = 
# 123 "<standard.mly>"
    ( None )
# 6855 "asllib/Parser.ml"
       in
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 6860 "asllib/Parser.ml"
       : (string * AST.ty option))
  
  let _menhir_action_233 =
    fun x x_inlined1 ->
      let y =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 6870 "asllib/Parser.ml"
        
      in
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 6876 "asllib/Parser.ml"
       : (string * AST.ty option))
  
  let _menhir_action_234 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6884 "asllib/Parser.ml"
       : (AST.ty option))
  
  let _menhir_action_235 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 6892 "asllib/Parser.ml"
       : (AST.ty option))
  
  let _menhir_action_236 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6900 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_237 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 6908 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_238 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 6916 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_239 =
    fun _1 _2 ->
      let x = _2 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 6925 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_240 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 6933 "asllib/Parser.ml"
       : (AST.stmt option))
  
  let _menhir_action_241 =
    fun _1 _2 _3 ->
      let x = _3 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 6942 "asllib/Parser.ml"
       : (AST.stmt option))
  
  let _menhir_action_242 =
    fun () ->
      (
# 578 "asllib/Parser.mly"
                  ( [] )
# 6950 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_243 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 6958 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_244 =
    fun _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern ->
      let desc = 
# 342 "asllib/Parser.mly"
                        Pattern_Single  
# 6966 "asllib/Parser.ml"
       expr_pattern in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_pattern_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6974 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_245 =
    fun _2 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc = 
# 343 "asllib/Parser.mly"
                                           Pattern_Range  
# 6982 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6990 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_246 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 344 "asllib/Parser.mly"
             ( Pattern_All )
# 6998 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7006 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_247 =
    fun _1 _endpos_expr_ _startpos__1_ expr ->
      let desc = 
# 345 "asllib/Parser.mly"
                     Pattern_Leq  
# 7014 "asllib/Parser.ml"
       expr in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7022 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_248 =
    fun _1 _endpos_expr_ _startpos__1_ expr ->
      let desc = 
# 346 "asllib/Parser.mly"
                     Pattern_Geq  
# 7030 "asllib/Parser.ml"
       expr in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7038 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_249 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let _1 = 
# 205 "<standard.mly>"
    ( x )
# 7047 "asllib/Parser.ml"
         in
        let _1_1 = _1 in
        
# 347 "asllib/Parser.mly"
                           Pattern_Tuple  
# 7053 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7062 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_250 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 337 "asllib/Parser.mly"
                                            Pattern_Mask  
# 7072 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7081 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_251 =
    fun _1 ->
      (_1 : (AST.pattern))
  
  let _menhir_action_252 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 338 "asllib/Parser.mly"
                                                   Pattern_Any  
# 7095 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7104 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_253 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 7112 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_254 =
    fun _1 _endpos__3_ _startpos__1_ x ->
      let desc =
        let _2 = 
# 205 "<standard.mly>"
    ( x )
# 7121 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        
# 355 "asllib/Parser.mly"
                                      Pattern_Not  
# 7127 "asllib/Parser.ml"
         _2_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7136 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_255 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 7144 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_256 =
    fun _1 _2 ->
      let x = _2 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 7153 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_257 =
    fun _1 _2 ->
      (_2 : (AST.ty))
  
  let _menhir_action_258 =
    fun _1 _3 _endpos_s2_ _startpos__1_ e s1 s2 ->
      let desc = 
# 560 "asllib/Parser.mly"
                                                     S_Cond 
# 7165 "asllib/Parser.ml"
       (e, s1, s2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_s2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = if _startpos_desc_ != _endpos_desc_ then
        _startpos_desc_
      else
        _endpos in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7176 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_259 =
    fun _endpos__0_ ->
      let desc = 
# 489 "asllib/Parser.mly"
            ( S_Pass )
# 7184 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__0_, _endpos__0_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = if _startpos_desc_ != _endpos_desc_ then
        _startpos_desc_
      else
        _endpos in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7195 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_260 =
    fun _1 _2 ->
      (_2 : (AST.stmt))
  
  let _menhir_action_261 =
    fun expr ->
      (
# 366 "asllib/Parser.mly"
                                    Slice_Single   
# 7207 "asllib/Parser.ml"
       expr : (AST.slice))
  
  let _menhir_action_262 =
    fun _2 e1 e2 ->
      (
# 367 "asllib/Parser.mly"
                                    Slice_Range    
# 7215 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_263 =
    fun _2 e1 e2 ->
      (
# 368 "asllib/Parser.mly"
                                    Slice_Length   
# 7223 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_264 =
    fun _1 e ->
      (
# 369 "asllib/Parser.mly"
                                  ( Slice_Length(zero, e) )
# 7231 "asllib/Parser.ml"
       : (AST.slice))
  
  let _menhir_action_265 =
    fun _2 e1 e2 ->
      (
# 370 "asllib/Parser.mly"
                                    Slice_Star     
# 7239 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_266 =
    fun basic_lexpr ->
      (basic_lexpr : (Desugar.lhs_access))
  
  let _menhir_action_267 =
    fun _endpos_desc_ _startpos_desc_ basic desc ->
      let slices =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7254 "asllib/Parser.ml"
        
      in
      (
# 434 "asllib/Parser.mly"
                                                 ( {basic with slices} )
# 7260 "asllib/Parser.ml"
       : (Desugar.lhs_access))
  
  let _menhir_action_268 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 7268 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_269 =
    fun x ->
      let _1 = 
# 196 "<standard.mly>"
    ( x )
# 7276 "asllib/Parser.ml"
       in
      let _1_1 = _1 in
      (
# 683 "asllib/Parser.mly"
                                             List.concat  
# 7282 "asllib/Parser.ml"
       _1_1 : (AST.t))
  
  let _menhir_action_270 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ e s1 s2 ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 515 "asllib/Parser.mly"
                                                       S_Cond 
# 7295 "asllib/Parser.ml"
         (e, s1, s2) in
        
# 196 "<standard.mly>"
    ( x )
# 7300 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7309 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_271 =
    fun _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ e s1 s2 ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7325 "asllib/Parser.ml"
          
        in
        let x = 
# 515 "asllib/Parser.mly"
                                                       S_Cond 
# 7331 "asllib/Parser.ml"
         (e, s1, s2) in
        
# 196 "<standard.mly>"
    ( x )
# 7336 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7345 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_272 =
    fun _1 _1_inlined1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ expr ->
      let desc =
        let _2 =
          let _1 = _1_inlined2 in
          ()
        in
        let x =
          let alt = _1_inlined1 in
          
# 517 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt (S_Unreachable |> ASTUtils.add_pos_from expr))
# 7360 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7366 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7375 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_273 =
    fun _1 _1_inlined1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ expr ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7391 "asllib/Parser.ml"
          
        in
        let x =
          let alt = _1_inlined1 in
          
# 517 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt (S_Unreachable |> ASTUtils.add_pos_from expr))
# 7399 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7405 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7414 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_274 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr otherwise_stmt ->
      let desc =
        let _2 =
          let _1 = _1_inlined3 in
          ()
        in
        let x =
          let _2 = _2_inlined1 in
          let case_otherwise =
            let _1 = _1_inlined2 in
            
# 501 "asllib/Parser.mly"
      ( otherwise_stmt )
# 7431 "asllib/Parser.ml"
            
          in
          let alt = _1_inlined1 in
          
# 519 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt case_otherwise )
# 7438 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7444 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7453 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_275 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ expr otherwise_stmt ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7469 "asllib/Parser.ml"
          
        in
        let x =
          let _2 = _2_inlined1 in
          let case_otherwise =
            let _1 = _1_inlined2 in
            
# 501 "asllib/Parser.mly"
      ( otherwise_stmt )
# 7479 "asllib/Parser.ml"
            
          in
          let alt = _1_inlined1 in
          
# 519 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt case_otherwise )
# 7486 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7492 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7501 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_276 =
    fun _1 _1_inlined1 _2 _4 _endpos__2_ _startpos__1_ expr loop_limit stmt_list ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 520 "asllib/Parser.mly"
                                                       S_While 
# 7514 "asllib/Parser.ml"
         (expr, loop_limit, stmt_list) in
        
# 196 "<standard.mly>"
    ( x )
# 7519 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7528 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_277 =
    fun _1 _1_inlined1 _4 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ expr loop_limit stmt_list ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7544 "asllib/Parser.ml"
          
        in
        let x = 
# 520 "asllib/Parser.mly"
                                                       S_While 
# 7550 "asllib/Parser.ml"
         (expr, loop_limit, stmt_list) in
        
# 196 "<standard.mly>"
    ( x )
# 7555 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7564 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_278 =
    fun _1 _1_inlined1 _2 _3 _8 _endpos__2_ _startpos__1_ body dir end_e index_name limit start_e ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 523 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 7577 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 7582 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7591 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_279 =
    fun _1 _1_inlined1 _3 _8 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ body dir end_e index_name limit start_e ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7607 "asllib/Parser.ml"
          
        in
        let x = 
# 523 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 7613 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 7618 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7627 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_280 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ c o s ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 524 "asllib/Parser.mly"
                                                                      S_Try  
# 7640 "asllib/Parser.ml"
         (s, c, o) in
        
# 196 "<standard.mly>"
    ( x )
# 7645 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7654 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_281 =
    fun _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ c o s ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 193 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7670 "asllib/Parser.ml"
          
        in
        let x = 
# 524 "asllib/Parser.mly"
                                                                      S_Try  
# 7676 "asllib/Parser.ml"
         (s, c, o) in
        
# 196 "<standard.mly>"
    ( x )
# 7681 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7690 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_282 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x = 
# 489 "asllib/Parser.mly"
            ( S_Pass )
# 7699 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 7704 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7713 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_283 =
    fun _1 _2_inlined1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let _2_1 = _2 in
          
# 528 "asllib/Parser.mly"
                                                              S_Return  
# 7725 "asllib/Parser.ml"
           _2_1
        in
        
# 196 "<standard.mly>"
    ( x )
# 7731 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7740 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_284 =
    fun _endpos__2_ _startpos_call_ call ->
      let desc =
        let x = 
# 529 "asllib/Parser.mly"
                                                               s_call  
# 7749 "asllib/Parser.ml"
         call in
        
# 196 "<standard.mly>"
    ( x )
# 7754 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7763 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_285 =
    fun _1 _endpos__2_ _startpos__1_ e ->
      let desc =
        let x = 
# 530 "asllib/Parser.mly"
                                                               S_Assert  
# 7772 "asllib/Parser.ml"
         e in
        
# 196 "<standard.mly>"
    ( x )
# 7777 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7786 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_286 =
    fun _4 _endpos__2_ _startpos_local_decl_keyword_non_var_ decl_item local_decl_keyword_non_var x ->
      let desc =
        let x =
          let _5 = 
# 149 "asllib/Parser.mly"
                        Some 
# 7796 "asllib/Parser.ml"
           x in
          let ty_opt = 
# 123 "<standard.mly>"
    ( None )
# 7801 "asllib/Parser.ml"
           in
          let _5_1 = _5 in
          
# 531 "asllib/Parser.mly"
                                                                                 S_Decl    
# 7807 "asllib/Parser.ml"
           (local_decl_keyword_non_var, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 7813 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_local_decl_keyword_non_var_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7822 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_287 =
    fun _4 _endpos__2_ _startpos_local_decl_keyword_non_var_ decl_item local_decl_keyword_non_var x x_inlined1 ->
      let desc =
        let x =
          let _5 =
            let x = x_inlined1 in
            
# 149 "asllib/Parser.mly"
                        Some 
# 7834 "asllib/Parser.ml"
             x
          in
          let ty_opt = 
# 126 "<standard.mly>"
    ( Some x )
# 7840 "asllib/Parser.ml"
           in
          let _5_1 = _5 in
          
# 531 "asllib/Parser.mly"
                                                                                 S_Decl    
# 7846 "asllib/Parser.ml"
           (local_decl_keyword_non_var, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 7852 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_local_decl_keyword_non_var_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7861 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_288 =
    fun _2_inlined1 _endpos__2_ _startpos_le_ e le ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          
# 532 "asllib/Parser.mly"
                                                               S_Assign  
# 7872 "asllib/Parser.ml"
           (le, e)
        in
        
# 196 "<standard.mly>"
    ( x )
# 7878 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_le_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7887 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_289 =
    fun _2_inlined1 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7901 "asllib/Parser.ml"
            
          in
          
# 534 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 7907 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7913 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7922 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_290 =
    fun _2_inlined1 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ desc fld rhs ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7936 "asllib/Parser.ml"
            
          in
          
# 536 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 7942 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7948 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7957 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_291 =
    fun _2_inlined1 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs x ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let flds = 
# 205 "<standard.mly>"
    ( x )
# 7968 "asllib/Parser.ml"
           in
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7976 "asllib/Parser.ml"
            
          in
          
# 538 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 7982 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 7988 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7997 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_292 =
    fun _4 _endpos__2_ _endpos_desc_ _startpos_desc_ _startpos_ldk_ desc ldk lhs ty ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8010 "asllib/Parser.ml"
            
          in
          
# 540 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs ty call)
# 8016 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8022 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_ldk_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8031 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_293 =
    fun _1 _endpos__2_ _startpos__1_ e ldi ->
      let desc =
        let x =
          let ty = 
# 123 "<standard.mly>"
    ( None )
# 8041 "asllib/Parser.ml"
           in
          
# 541 "asllib/Parser.mly"
                                                              ( S_Decl (LDK_Var, ldi, ty, e) )
# 8046 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8052 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8061 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_294 =
    fun _1 _endpos__2_ _startpos__1_ e ldi x ->
      let desc =
        let x =
          let ty = 
# 126 "<standard.mly>"
    ( Some x )
# 8071 "asllib/Parser.ml"
           in
          
# 541 "asllib/Parser.mly"
                                                              ( S_Decl (LDK_Var, ldi, ty, e) )
# 8076 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8082 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8091 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_295 =
    fun _1 _2_inlined1 _endpos__2_ _startpos__1_ as_ty ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let _2_1 = _2 in
          
# 542 "asllib/Parser.mly"
                                                               make_ldi_vars  
# 8103 "asllib/Parser.ml"
           (_2_1, as_ty)
        in
        
# 196 "<standard.mly>"
    ( x )
# 8109 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8118 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_296 =
    fun _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8131 "asllib/Parser.ml"
            
          in
          
# 544 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs ty call)
# 8137 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8143 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8152 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_297 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 8162 "asllib/Parser.ml"
           in
          
# 545 "asllib/Parser.mly"
                                                              ( S_Print { args; newline = true; debug = false } )
# 8167 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8173 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8182 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_298 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 8192 "asllib/Parser.ml"
           in
          
# 546 "asllib/Parser.mly"
                                                              ( S_Print { args; newline = false; debug = false } )
# 8197 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8203 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8212 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_299 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 8222 "asllib/Parser.ml"
           in
          
# 547 "asllib/Parser.mly"
                                             ( S_Print { args; newline = true; debug = true } )
# 8227 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8233 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8242 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_300 =
    fun _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          
# 548 "asllib/Parser.mly"
                                                             ( S_Unreachable )
# 8253 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 8259 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8268 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_301 =
    fun _1 _3 _endpos__2_ _startpos__1_ expr loop_limit stmt_list ->
      let desc =
        let x = 
# 549 "asllib/Parser.mly"
                                                               S_Repeat  
# 8277 "asllib/Parser.ml"
         (stmt_list, expr, loop_limit) in
        
# 196 "<standard.mly>"
    ( x )
# 8282 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8291 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_302 =
    fun _1 _endpos__2_ _startpos__1_ e ->
      let desc =
        let x = 
# 550 "asllib/Parser.mly"
                                                             ( S_Throw (Some (e, None)) )
# 8300 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 8305 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8314 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_303 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x = 
# 551 "asllib/Parser.mly"
                                                             ( S_Throw None             )
# 8323 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 8328 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8337 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_304 =
    fun _1 _endpos__2_ _startpos__1_ e x ->
      let desc =
        let x = 
# 552 "asllib/Parser.mly"
                                                                S_Pragma  
# 8346 "asllib/Parser.ml"
         (x, e) in
        
# 196 "<standard.mly>"
    ( x )
# 8351 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8360 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_305 =
    fun _1 ->
      let _1_1 = _1 in
      (
# 556 "asllib/Parser.mly"
                                    stmt_from_list 
# 8369 "asllib/Parser.ml"
       _1_1 : (AST.stmt))
  
  let _menhir_action_306 =
    fun x ->
      (
# 196 "<standard.mly>"
    ( x )
# 8377 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_307 =
    fun _1 _2 ->
      let with_opt = 
# 571 "asllib/Parser.mly"
                ( [] )
# 8385 "asllib/Parser.ml"
       in
      let _2_1 = _2 in
      ((_2_1, with_opt) : (string * AST.field list))
  
  let _menhir_action_308 =
    fun _1 _1_inlined1 _2 fields ->
      let with_opt =
        let _1 = _1_inlined1 in
        fields
      in
      let _2_1 = _2 in
      ((_2_1, with_opt) : (string * AST.field list))
  
  let _menhir_action_309 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 8404 "asllib/Parser.ml"
       : ((string * AST.field list) option))
  
  let _menhir_action_310 =
    fun x ->
      (
# 126 "<standard.mly>"
    ( Some x )
# 8412 "asllib/Parser.ml"
       : ((string * AST.field list) option))
  
  let _menhir_action_311 =
    fun () ->
      (
# 173 "asllib/Parser.mly"
                  ( [] )
# 8420 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_312 =
    fun _1 ->
      (_1 : (AST.bitfield list))
  
  let _menhir_action_313 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 8432 "asllib/Parser.ml"
       in
      (
# 177 "asllib/Parser.mly"
                         ( [ x ] )
# 8437 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_314 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 8447 "asllib/Parser.ml"
        
      in
      (
# 177 "asllib/Parser.mly"
                         ( [ x ] )
# 8453 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_315 =
    fun _2 h t ->
      (
# 178 "asllib/Parser.mly"
                              ( h :: t )
# 8461 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_316 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 8469 "asllib/Parser.ml"
       in
      (
# 177 "asllib/Parser.mly"
                         ( [ x ] )
# 8474 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_317 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 8484 "asllib/Parser.ml"
        
      in
      (
# 177 "asllib/Parser.mly"
                         ( [ x ] )
# 8490 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_318 =
    fun _2 h t ->
      (
# 178 "asllib/Parser.mly"
                              ( h :: t )
# 8498 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_319 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 8506 "asllib/Parser.ml"
       in
      (
# 177 "asllib/Parser.mly"
                         ( [ x ] )
# 8511 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_320 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 8521 "asllib/Parser.ml"
        
      in
      (
# 177 "asllib/Parser.mly"
                         ( [ x ] )
# 8527 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_321 =
    fun _2 h t ->
      (
# 178 "asllib/Parser.mly"
                              ( h :: t )
# 8535 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_322 =
    fun _1 _endpos_c_ _startpos__1_ c ->
      let desc = 
# 383 "asllib/Parser.mly"
                                                          T_Int         
# 8543 "asllib/Parser.ml"
       c in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_c_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8551 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_323 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 384 "asllib/Parser.mly"
                                                        ( T_Real       )
# 8559 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8567 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_324 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 385 "asllib/Parser.mly"
                                                        ( T_Bool       )
# 8575 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8583 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_325 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 386 "asllib/Parser.mly"
                                                        ( T_String     )
# 8591 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8599 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_326 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 387 "asllib/Parser.mly"
                                                        ( t_bit        )
# 8607 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8615 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_327 =
    fun _1 _endpos_bitfields_opt_ _startpos__1_ bitfields_opt x ->
      let desc =
        let _2 = 
# 205 "<standard.mly>"
    ( x )
# 8624 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        
# 388 "asllib/Parser.mly"
                                                          T_Bits        
# 8630 "asllib/Parser.ml"
         (_2_1, bitfields_opt)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_bitfields_opt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8639 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_328 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let l = 
# 205 "<standard.mly>"
    ( x )
# 8648 "asllib/Parser.ml"
         in
        
# 389 "asllib/Parser.mly"
                                                          T_Tuple       
# 8653 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8662 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_329 =
    fun _endpos_name_ _startpos_name_ name ->
      let desc = 
# 390 "asllib/Parser.mly"
                                                          T_Named       
# 8670 "asllib/Parser.ml"
       name in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_name_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8678 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_330 =
    fun _1 _2 _4 _5 _endpos_t_ _startpos__1_ e t ->
      let desc = 
# 391 "asllib/Parser.mly"
                                                        ( T_Array (ArrayLength_Expr e, t) )
# 8686 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_t_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8694 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_331 =
    fun _1 ->
      (_1 : (AST.ty))
  
  let _menhir_action_332 =
    fun _1 _endpos__3_ _startpos__1_ x ->
      let desc =
        let l = 
# 205 "<standard.mly>"
    ( x )
# 8707 "asllib/Parser.ml"
         in
        
# 396 "asllib/Parser.mly"
                                                          T_Enum        
# 8712 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8721 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_333 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 397 "asllib/Parser.mly"
                                                          T_Record      
# 8729 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8737 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_334 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 398 "asllib/Parser.mly"
                                                          T_Exception   
# 8745 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8753 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_335 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 399 "asllib/Parser.mly"
                                                          T_Collection  
# 8761 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 156 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8769 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_336 =
    fun x y ->
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 8777 "asllib/Parser.ml"
       : (AST.field))
  
  let _menhir_action_337 =
    fun i ->
      (
# 206 "asllib/Parser.mly"
                        L_Int          
# 8785 "asllib/Parser.ml"
       i : (AST.literal))
  
  let _menhir_action_338 =
    fun b ->
      (
# 207 "asllib/Parser.mly"
                        L_Bool         
# 8793 "asllib/Parser.ml"
       b : (AST.literal))
  
  let _menhir_action_339 =
    fun r ->
      (
# 208 "asllib/Parser.mly"
                        L_Real         
# 8801 "asllib/Parser.ml"
       r : (AST.literal))
  
  let _menhir_action_340 =
    fun b ->
      (
# 209 "asllib/Parser.mly"
                        L_BitVector    
# 8809 "asllib/Parser.ml"
       b : (AST.literal))
  
  let _menhir_action_341 =
    fun s ->
      (
# 210 "asllib/Parser.mly"
                        L_String       
# 8817 "asllib/Parser.ml"
       s : (AST.literal))
  
  let _menhir_print_token : token -> string =
    fun _tok ->
      match _tok with
      | Tokens.ACCESSOR ->
          "ACCESSOR"
      | Tokens.AND ->
          "AND"
      | Tokens.ARBITRARY ->
          "ARBITRARY"
      | Tokens.ARRAY ->
          "ARRAY"
      | Tokens.ARROW ->
          "ARROW"
      | Tokens.AS ->
          "AS"
      | Tokens.ASSERT ->
          "ASSERT"
      | Tokens.BAND ->
          "BAND"
      | Tokens.BEGIN ->
          "BEGIN"
      | Tokens.BEQ ->
          "BEQ"
      | Tokens.BIARROW ->
          "BIARROW"
      | Tokens.BIT ->
          "BIT"
      | Tokens.BITS ->
          "BITS"
      | Tokens.BITVECTOR_LIT _ ->
          "BITVECTOR_LIT"
      | Tokens.BNOT ->
          "BNOT"
      | Tokens.BOOLEAN ->
          "BOOLEAN"
      | Tokens.BOOL_LIT _ ->
          "BOOL_LIT"
      | Tokens.BOR ->
          "BOR"
      | Tokens.CASE ->
          "CASE"
      | Tokens.CATCH ->
          "CATCH"
      | Tokens.COLLECTION ->
          "COLLECTION"
      | Tokens.COLON ->
          "COLON"
      | Tokens.COLON_COLON ->
          "COLON_COLON"
      | Tokens.COMMA ->
          "COMMA"
      | Tokens.CONFIG ->
          "CONFIG"
      | Tokens.CONSTANT ->
          "CONSTANT"
      | Tokens.DEBUG ->
          "DEBUG"
      | Tokens.DIV ->
          "DIV"
      | Tokens.DIVRM ->
          "DIVRM"
      | Tokens.DO ->
          "DO"
      | Tokens.DOT ->
          "DOT"
      | Tokens.DOWNTO ->
          "DOWNTO"
      | Tokens.ELSE ->
          "ELSE"
      | Tokens.ELSIF ->
          "ELSIF"
      | Tokens.END ->
          "END"
      | Tokens.ENUMERATION ->
          "ENUMERATION"
      | Tokens.EOF ->
          "EOF"
      | Tokens.EQ ->
          "EQ"
      | Tokens.EQ_OP ->
          "EQ_OP"
      | Tokens.EXCEPTION ->
          "EXCEPTION"
      | Tokens.FOR ->
          "FOR"
      | Tokens.FUNC ->
          "FUNC"
      | Tokens.GEQ ->
          "GEQ"
      | Tokens.GETTER ->
          "GETTER"
      | Tokens.GT ->
          "GT"
      | Tokens.IDENTIFIER _ ->
          "IDENTIFIER"
      | Tokens.IF ->
          "IF"
      | Tokens.IMPDEF ->
          "IMPDEF"
      | Tokens.IMPL ->
          "IMPL"
      | Tokens.IMPLEMENTATION ->
          "IMPLEMENTATION"
      | Tokens.IN ->
          "IN"
      | Tokens.INTEGER ->
          "INTEGER"
      | Tokens.INT_LIT _ ->
          "INT_LIT"
      | Tokens.LBRACE ->
          "LBRACE"
      | Tokens.LBRACKET ->
          "LBRACKET"
      | Tokens.LEQ ->
          "LEQ"
      | Tokens.LET ->
          "LET"
      | Tokens.LLBRACKET ->
          "LLBRACKET"
      | Tokens.LOOPLIMIT ->
          "LOOPLIMIT"
      | Tokens.LPAR ->
          "LPAR"
      | Tokens.LT ->
          "LT"
      | Tokens.MASK_LIT _ ->
          "MASK_LIT"
      | Tokens.MINUS ->
          "MINUS"
      | Tokens.MOD ->
          "MOD"
      | Tokens.MUL ->
          "MUL"
      | Tokens.NEQ ->
          "NEQ"
      | Tokens.NOT ->
          "NOT"
      | Tokens.OF ->
          "OF"
      | Tokens.OR ->
          "OR"
      | Tokens.OTHERWISE ->
          "OTHERWISE"
      | Tokens.PASS ->
          "PASS"
      | Tokens.PLUS ->
          "PLUS"
      | Tokens.PLUS_COLON ->
          "PLUS_COLON"
      | Tokens.POW ->
          "POW"
      | Tokens.PRAGMA ->
          "PRAGMA"
      | Tokens.PRINT ->
          "PRINT"
      | Tokens.PRINTLN ->
          "PRINTLN"
      | Tokens.RBRACE ->
          "RBRACE"
      | Tokens.RBRACKET ->
          "RBRACKET"
      | Tokens.RDIV ->
          "RDIV"
      | Tokens.REAL ->
          "REAL"
      | Tokens.REAL_LIT _ ->
          "REAL_LIT"
      | Tokens.RECORD ->
          "RECORD"
      | Tokens.RECURSELIMIT ->
          "RECURSELIMIT"
      | Tokens.REPEAT ->
          "REPEAT"
      | Tokens.RETURN ->
          "RETURN"
      | Tokens.RPAR ->
          "RPAR"
      | Tokens.RRBRACKET ->
          "RRBRACKET"
      | Tokens.SEMI_COLON ->
          "SEMI_COLON"
      | Tokens.SETTER ->
          "SETTER"
      | Tokens.SHL ->
          "SHL"
      | Tokens.SHR ->
          "SHR"
      | Tokens.SLICING ->
          "SLICING"
      | Tokens.STAR_COLON ->
          "STAR_COLON"
      | Tokens.STRING ->
          "STRING"
      | Tokens.STRING_LIT _ ->
          "STRING_LIT"
      | Tokens.SUBTYPES ->
          "SUBTYPES"
      | Tokens.THEN ->
          "THEN"
      | Tokens.THROW ->
          "THROW"
      | Tokens.TO ->
          "TO"
      | Tokens.TRY ->
          "TRY"
      | Tokens.TYPE ->
          "TYPE"
      | Tokens.UNREACHABLE ->
          "UNREACHABLE"
      | Tokens.UNTIL ->
          "UNTIL"
      | Tokens.VAR ->
          "VAR"
      | Tokens.WHEN ->
          "WHEN"
      | Tokens.WHERE ->
          "WHERE"
      | Tokens.WHILE ->
          "WHILE"
      | Tokens.WITH ->
          "WITH"
      | Tokens.XOR ->
          "XOR"
  
  let _menhir_fail : unit -> 'a =
    fun () ->
      Printf.eprintf "Internal failure -- please contact the parser generator's developers.\n%!";
      assert false
  
  include struct
    
    [@@@ocaml.warning "-4-37"]
    
    let _menhir_run_549 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let (_2, body) = ((), _v) in
            let _v = _menhir_action_231 _2 body in
            MenhirBox_opn _v
        | _ ->
            _eRR ()
    
    let _menhir_run_748 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_stmts =
      fun _menhir_stack _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let x = _v in
            let _v = _menhir_action_306 x in
            MenhirBox_stmts _v
        | _ ->
            _eRR ()
    
    let _menhir_run_735 : type  ttv_stack. ttv_stack -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let x = _v in
        let _v = _menhir_action_269 x in
        MenhirBox_spec _v
    
    let rec _menhir_run_745 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_decl -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_decl (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_216 x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_goto_list_decl_ : type  ttv_stack. ttv_stack -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _v _menhir_s ->
        match _menhir_s with
        | MenhirState744 ->
            _menhir_run_745 _menhir_stack _v
        | MenhirState552 ->
            _menhir_run_735 _menhir_stack _v
        | _ ->
            _menhir_fail ()
    
    let rec _menhir_run_001 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState001 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_002 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_341 s in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_goto_value : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState450 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState740 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState720 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState634 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState602 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState558 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState522 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState491 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState475 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState452 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState447 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState442 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState437 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState433 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState410 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState390 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState381 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState376 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState371 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState365 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState361 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState336 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState338 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState343 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState331 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState310 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState299 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState279 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState272 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState270 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState268 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState266 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState033 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState248 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState243 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState241 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState239 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState237 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState235 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState233 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState225 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState223 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState219 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState214 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState211 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState209 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState207 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState205 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState203 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState200 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState198 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState194 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState192 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState190 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState188 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState116 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState052 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState031 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState029 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState025 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_177 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_value_, _startpos_value_, value) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_154 _endpos_value_ _startpos_value_ value in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_value_ _startpos_value_ _v _menhir_s _tok
    
    and _menhir_goto_expr_pattern : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState055 ->
            _menhir_run_258 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState450 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_258 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_186 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_195 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_192 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_221 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_225 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_228 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_233 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_235 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_237 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_239 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_241 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_243 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_245 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_248 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState258
        | Tokens.COMMA ->
            let (_endpos_expr_pattern_, _startpos_expr_pattern_, expr_pattern) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_244 _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_pattern_ _startpos_expr_pattern_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_184 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_XOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState184 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_003 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_r_, _startpos_r_, r) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_339 r in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_r_ _v _menhir_s _tok
    
    and _menhir_run_004 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState004 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_005 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState005 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_006 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState006 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_007 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_i_, _startpos_i_, i) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_337 i in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_i_ _startpos_i_ _v _menhir_s _tok
    
    and _menhir_run_008 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState008 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_009 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState009
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState009
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_110 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_010 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.RPAR ->
            let _v = _menhir_action_027 () in
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_011 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_338 b in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_012 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState012 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_013 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_340 b in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_014 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _menhir_s = MenhirState015 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_016 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_325 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_ty : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState631 ->
            _menhir_run_632 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState579 ->
            _menhir_run_598 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState528 ->
            _menhir_run_534 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState530 ->
            _menhir_run_531 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState015 ->
            _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState289 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState245 ->
            _menhir_run_246 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState175 ->
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState100 ->
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState113 ->
            _menhir_run_121 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState119 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_632 : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_ARROW -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ARROW (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _2) = ((), _v) in
        let _v = _menhir_action_257 _1 _2 in
        _menhir_goto_return_type _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_return_type : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState705 ->
            _menhir_run_710 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState680 ->
            _menhir_run_685 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState625 ->
            _menhir_run_633 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_710 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_634 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState710
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_255 () in
            _menhir_run_711 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState710
        | _ ->
            _eRR ()
    
    and _menhir_run_634 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RECURSELIMIT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState634 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_711 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState712
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_228 _endpos__0_
            in
            _menhir_run_713 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_314 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState314
        | Tokens.LPAR ->
            _menhir_run_316 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState314
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState314, _v, _startpos_0, _endpos) in
                _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Tokens.COLON | Tokens.EQ | Tokens.SEMI_COLON ->
                let _v =
                  let _1 = _v in
                  _menhir_action_093 _1
                in
                _menhir_run_330 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState314 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_315 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_092 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_decl_item : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState461 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState314 ->
            _menhir_run_330 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_463 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState463) in
            let _menhir_s = MenhirState464 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | _ ->
            _eRR ()
    
    and _menhir_run_113 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState113 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_017 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_323 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_018 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState018 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RPAR ->
            let _v = _menhir_action_029 () in
            _menhir_goto_clist0_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_019 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState019 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RECURSELIMIT | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.SUBTYPES | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let _v = _menhir_action_066 () in
            _menhir_goto_constraint_kind_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_020 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.MINUS ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.RBRACE ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_startpos__1_, x, _endpos__3_) = (_startpos, (), _endpos_1) in
                let _v = _menhir_action_064 x in
                _menhir_goto_constraint_kind _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
            | _ ->
                _eRR ())
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | _ ->
            _eRR ()
    
    and _menhir_goto_constraint_kind : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState019 ->
            _menhir_run_287 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState245 ->
            _menhir_run_247 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState100 ->
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_287 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_INTEGER -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_065 _1 in
        _menhir_goto_constraint_kind_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
    
    and _menhir_goto_constraint_kind_opt : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_INTEGER -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_c_, c) = ((), _endpos, _v) in
        let _v = _menhir_action_322 _1 _endpos_c_ _startpos__1_ c in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _menhir_s _tok
    
    and _menhir_run_247 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_constraint_kind_, _startpos_constraint_kind_, constraint_kind) = ((), _endpos, _startpos, _v) in
        let _v = _menhir_action_190 _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_pattern_ constraint_kind expr_pattern in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_constraint_kind_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_130 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_constraint_kind_, _startpos_constraint_kind_, constraint_kind) = ((), _endpos, _startpos, _v) in
        let _v = _menhir_action_145 _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_ constraint_kind expr in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_constraint_kind_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_goto_expr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState740 ->
            _menhir_run_741 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState720 ->
            _menhir_run_721 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState634 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState558 ->
            _menhir_run_559 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState522 ->
            _menhir_run_523 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState491 ->
            _menhir_run_492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_488 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState475 ->
            _menhir_run_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_456 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState452 ->
            _menhir_run_453 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState447 ->
            _menhir_run_448 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState437 ->
            _menhir_run_438 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState433 ->
            _menhir_run_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState410 ->
            _menhir_run_411 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState390 ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState365 ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState361 ->
            _menhir_run_363 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState336 ->
            _menhir_run_332 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState331 ->
            _menhir_run_332 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState310 ->
            _menhir_run_311 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_309 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState299 ->
            _menhir_run_300 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_298 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_295 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_282 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_280 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState279 ->
            _menhir_run_280 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState272 ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState270 ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState268 ->
            _menhir_run_269 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState033 ->
            _menhir_run_267 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState266 ->
            _menhir_run_267 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_254 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState248 ->
            _menhir_run_249 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState243 ->
            _menhir_run_244 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState241 ->
            _menhir_run_242 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState239 ->
            _menhir_run_240 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState237 ->
            _menhir_run_238 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState235 ->
            _menhir_run_236 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState233 ->
            _menhir_run_234 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState225 ->
            _menhir_run_227 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState223 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_222 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState219 ->
            _menhir_run_220 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState214 ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState211 ->
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState209 ->
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState207 ->
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState205 ->
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState203 ->
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState200 ->
            _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState198 ->
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState194 ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState192 ->
            _menhir_run_193 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState190 ->
            _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState188 ->
            _menhir_run_189 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_185 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState602 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState442 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState381 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState376 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState371 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState338 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState343 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState116 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState052 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState031 ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState029 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState025 ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_741 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_option_as_ty_ (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_global_let_or_constant (_menhir_stack, _menhir_s, keyword, _startpos_keyword_) = _menhir_stack in
            let (_endpos__2_, x, _4) = (_endpos_0, _v, ()) in
            let _v = _menhir_action_081 _4 _endpos__2_ _startpos_keyword_ keyword name ty x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState741
        | _ ->
            _eRR ()
    
    and _menhir_run_027 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_XOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState027 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_029 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState029 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_036 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState036 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_decl : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_553 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.TYPE ->
            _menhir_run_563 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.PRAGMA ->
            _menhir_run_601 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.LET ->
            _menhir_run_605 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.IMPLEMENTATION ->
            _menhir_run_606 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.IMPDEF ->
            _menhir_run_676 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.FUNC ->
            _menhir_run_702 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.CONSTANT ->
            _menhir_run_716 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.CONFIG ->
            _menhir_run_717 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.ACCESSOR ->
            _menhir_run_723 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | Tokens.EOF ->
            let _v_0 = _menhir_action_215 () in
            _menhir_run_745 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_553 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState553 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_554 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_555 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_554 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_206 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ignored_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_ignored_or_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState737 ->
            _menhir_run_738 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState717 ->
            _menhir_run_718 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState553 ->
            _menhir_run_556 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_738 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_global_let_or_constant as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState738
        | Tokens.EQ ->
            let _v_0 = _menhir_action_234 () in
            _menhir_run_739 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState738 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_739 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_option_as_ty_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState740 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_718 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | _ ->
            _eRR ()
    
    and _menhir_run_556 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState556
        | Tokens.EQ ->
            let _v_0 = _menhir_action_234 () in
            _menhir_run_557 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState556 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_557 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_option_as_ty_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState558 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_555 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = _v in
        let _v = _menhir_action_207 _1 in
        _menhir_goto_ignored_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_563 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SUBTYPES ->
                _menhir_run_565 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState564
            | Tokens.OF ->
                let _menhir_stack = MenhirCell1_OF (_menhir_stack, MenhirState564) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | Tokens.RECORD ->
                    let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_RECORD (_menhir_stack, MenhirState579, _startpos_1) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_568 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState580
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let _v_3 = _menhir_action_201 () in
                        _menhir_run_581 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_2 _v_3 _tok
                    | _ ->
                        _eRR ())
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | Tokens.IDENTIFIER _v_4 ->
                    _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState579
                | Tokens.EXCEPTION ->
                    let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_EXCEPTION (_menhir_stack, MenhirState579, _startpos_5) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_568 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState583
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let _v_7 = _menhir_action_201 () in
                        _menhir_run_584 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_6 _v_7 _tok
                    | _ ->
                        _eRR ())
                | Tokens.ENUMERATION ->
                    let _menhir_s = MenhirState579 in
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _menhir_stack = MenhirCell1_ENUMERATION (_menhir_stack, _menhir_s, _startpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
                        let _menhir_s = MenhirState586 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_587 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.COLLECTION ->
                    let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_COLLECTION (_menhir_stack, MenhirState579, _startpos_11) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_568 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState592
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let _v_13 = _menhir_action_201 () in
                        _menhir_run_593 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_12 _v_13 _tok
                    | _ ->
                        _eRR ())
                | Tokens.BOOLEAN ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | Tokens.BITS ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | Tokens.BIT ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | Tokens.ARRAY ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_565 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WITH ->
                let _menhir_stack = MenhirCell1_SUBTYPES (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                let _menhir_s = MenhirState567 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_568 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let (_startpos__1_, _1, _endpos__2_, _2) = (_startpos, (), _endpos, _v) in
                let _v = _menhir_action_307 _1 _2 in
                _menhir_goto_subtype _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _startpos__1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_568 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RBRACE ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (x, _endpos__3_) = ((), _endpos_1) in
                let _v = _menhir_action_199 x in
                _menhir_goto_fields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_571 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState568
        | _ ->
            _eRR ()
    
    and _menhir_goto_fields : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState592 ->
            _menhir_run_582 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState583 ->
            _menhir_run_582 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState580 ->
            _menhir_run_582 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState567 ->
            _menhir_run_578 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_582 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_202 _1 in
        _menhir_goto_fields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_fields_opt : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState592 ->
            _menhir_run_593 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState583 ->
            _menhir_run_584 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState580 ->
            _menhir_run_581 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_593 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_COLLECTION -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_COLLECTION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_335 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_ty_decl : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SUBTYPES ->
            _menhir_run_565 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState594
        | Tokens.SEMI_COLON ->
            let _v = _menhir_action_309 () in
            _menhir_goto_subtype_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_subtype_opt : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_ty_decl (_menhir_stack, _, t) = _menhir_stack in
            let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3, subtype_opt) = ((), _endpos, (), _v) in
            let _v = _menhir_action_079 _1 _3 _endpos__2_ _startpos__1_ subtype_opt t x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_584 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_EXCEPTION -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_EXCEPTION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_334 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_581 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_RECORD -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RECORD (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_333 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_578 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_SUBTYPES _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2, _, _) = _menhir_stack in
        let MenhirCell1_SUBTYPES (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_fields_, fields, _1_inlined1) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_308 _1 _1_inlined1 _2 fields in
        _menhir_goto_subtype _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_fields_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_subtype : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState564 ->
            _menhir_run_599 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState594 ->
            _menhir_run_597 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_599 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc) = ((), _endpos_0, _endpos, _startpos, _v) in
            let _v = _menhir_action_080 _1 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_597 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let x = _v in
        let _v = _menhir_action_310 x in
        _menhir_goto_subtype_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
    
    and _menhir_run_571 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState571 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_101 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_name_, _startpos_name_, name) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_329 _endpos_name_ _startpos_name_ name in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_name_ _v _menhir_s _tok
    
    and _menhir_run_587 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                _menhir_run_587 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState588
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_314 x x_inlined1 in
                _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_313 x in
            _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_IDENTIFIER_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState586 ->
            _menhir_run_590 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState588 ->
            _menhir_run_589 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_590 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ENUMERATION _menhir_cell0_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ENUMERATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_332 _1 _endpos__3_ _startpos__1_ x in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_589 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_315 _2 h t in
        _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_102 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_324 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_103 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BITS (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState104 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_114 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_326 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_115 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARRAY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_s = MenhirState116 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_601 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState602
            | Tokens.REAL_LIT _v_2 ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState602
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState602
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState602
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState602
            | Tokens.INT_LIT _v_3 ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState602
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState602
            | Tokens.IDENTIFIER _v_4 ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState602
            | Tokens.BOOL_LIT _v_5 ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState602
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState602
            | Tokens.BITVECTOR_LIT _v_6 ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState602
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState602
            | Tokens.SEMI_COLON ->
                let _v_7 = _menhir_action_027 () in
                _menhir_run_603 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_603 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_085 _1 _endpos__2_ _startpos__1_ e x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_605 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_startpos__1_, _1) = (_startpos, ()) in
        let _v = _menhir_action_204 _1 in
        _menhir_goto_global_let_or_constant _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_global_let_or_constant : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_global_let_or_constant (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_554 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState737
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_555 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState737
        | _ ->
            _eRR ()
    
    and _menhir_run_606 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.FUNC ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_1, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState608
                | Tokens.LPAR ->
                    let _v_2 = _menhir_action_242 () in
                    _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState608 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.ACCESSOR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_3, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState642
                | Tokens.LPAR ->
                    let _v_4 = _menhir_action_242 () in
                    _menhir_run_643 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState642 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_609 : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState609 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_610 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_610 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState610
        | Tokens.COMMA | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_232 x in
            _menhir_goto_opt_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_opt_typed_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_opt_typed_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState613 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_610 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_047 x in
            _menhir_goto_clist1_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_opt_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState609 ->
            _menhir_run_615 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState613 ->
            _menhir_run_614 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_615 : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_243 x in
        _menhir_goto_params_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_params_opt : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState724 ->
            _menhir_run_725 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState703 ->
            _menhir_run_704 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState692 ->
            _menhir_run_693 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState678 ->
            _menhir_run_679 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState642 ->
            _menhir_run_643 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState608 ->
            _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_725 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_618 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState725
        | _ ->
            _eRR ()
    
    and _menhir_run_618 : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState618 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_571 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.RPAR ->
            let _v = _menhir_action_031 () in
            _menhir_goto_clist0_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist0_typed_identifier_ : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_203 x in
        _menhir_goto_func_args _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_func_args : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState725 ->
            _menhir_run_726 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState704 ->
            _menhir_run_705 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState693 ->
            _menhir_run_694 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState679 ->
            _menhir_run_680 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState643 ->
            _menhir_run_644 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState617 ->
            _menhir_run_625 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_726 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BIARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState728 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_705 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState705) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState706
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState706
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_228 _endpos__0_
                in
                _menhir_run_707 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_631 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState705
        | _ ->
            _eRR ()
    
    and _menhir_run_356 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RPAR ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SEMI_COLON ->
                    let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_startpos__1_, _1, _endpos__2_, _3, _2_inlined1) = (_startpos, (), _endpos_1, (), ()) in
                    let _v = _menhir_action_300 _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ in
                    _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_stmt : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState000 ->
            _menhir_run_549 _menhir_stack _v _tok
        | MenhirState746 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState706 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState664 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState653 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState649 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState637 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState626 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState360 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState539 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState535 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState532 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState440 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState495 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState459 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState454 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_459 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.PRINTLN ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState459
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState459
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_221 x in
            _menhir_goto_list1_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_360 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState360 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_361 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState361
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
            let _v = _menhir_action_303 _1 _endpos__2_ _startpos__1_ in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState361
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState361
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState361
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState361
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState361
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | _ ->
            _eRR ()
    
    and _menhir_run_365 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState365 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.SEMI_COLON ->
            let _v = _menhir_action_236 () in
            _menhir_goto_option_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_option_expr_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_RETURN -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos__2_, _2_inlined1) = ((), _endpos, _v) in
        let _v = _menhir_action_283 _1 _2_inlined1 _endpos__2_ _startpos__1_ in
        _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_run_369 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState369 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_370 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRINTLN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState371
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState371
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState371
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState371
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState371
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState371
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState371
            | Tokens.RPAR ->
                let _v = _menhir_action_027 () in
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_372 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRINTLN _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PRINTLN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_297 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_375 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState376
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState376
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState376
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState376
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState376
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState376
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState376
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState376
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState376
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState376
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState376
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState376
            | Tokens.RPAR ->
                let _v = _menhir_action_027 () in
                _menhir_run_377 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_377 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRINT _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_298 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_380 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState381
            | Tokens.REAL_LIT _v_2 ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState381
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState381
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState381
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState381
            | Tokens.INT_LIT _v_3 ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState381
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState381
            | Tokens.IDENTIFIER _v_4 ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState381
            | Tokens.BOOL_LIT _v_5 ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState381
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState381
            | Tokens.BITVECTOR_LIT _v_6 ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState381
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState381
            | Tokens.SEMI_COLON ->
                let _v_7 = _menhir_action_027 () in
                _menhir_run_382 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_382 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_304 _1 _endpos__2_ _startpos__1_ e x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_384 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
            let _v = _menhir_action_282 _1 _endpos__2_ _startpos__1_ in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_386 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_212 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_lexpr (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState475 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_387 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState387 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_388 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_101 _1 in
        _menhir_goto_discard_or_sliced_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_sliced_basic_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState402 ->
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState400 ->
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState387 ->
            _menhir_run_399 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_401 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_sliced_basic_lexpr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_sliced_basic_lexpr (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState402 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_039 x in
            _menhir_goto_clist1_discard_or_sliced_basic_lexpr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_389 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState389
        | Tokens.DOT ->
            _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState389
        | Tokens.COMMA | Tokens.LBRACKET | Tokens.RPAR ->
            let _v_0 = _menhir_action_229 () in
            _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_390 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState390 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_393 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_394 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.DOT ->
            _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState394
        | Tokens.COMMA | Tokens.EQ | Tokens.LBRACKET | Tokens.RPAR ->
            let _v_0 = _menhir_action_229 () in
            _menhir_run_395 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_395 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, t) = ((), _v) in
        let _v = _menhir_action_230 _1 _endpos_desc_ _startpos_desc_ desc t in
        _menhir_goto_nested_fields _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_nested_fields : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState413 ->
            _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState389 ->
            _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState392 ->
            _menhir_run_396 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState394 ->
            _menhir_run_395 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_397 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let fields = _v in
        let _v = _menhir_action_012 _endpos_desc_ _startpos_desc_ desc fields in
        _menhir_goto_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_goto_basic_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_basic_lexpr (_menhir_stack, _menhir_s, _v, _startpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState404
        | Tokens.COMMA | Tokens.EQ | Tokens.RPAR ->
            let (_startpos_basic_lexpr_, basic_lexpr) = (_startpos, _v) in
            let _v = _menhir_action_266 basic_lexpr in
            _menhir_goto_sliced_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_basic_lexpr_ _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_033 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState033 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.COLON ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_034 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState034 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_sliced_basic_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState746 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState706 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState664 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState653 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState649 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState637 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState626 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState360 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState539 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState535 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState532 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState440 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState495 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState454 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState459 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState402 ->
            _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState400 ->
            _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState387 ->
            _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_460 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let (_startpos_sliced_basic_lexpr_, sliced_basic_lexpr) = (_startpos, _v) in
        let _v = _menhir_action_210 sliced_basic_lexpr in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_sliced_basic_lexpr_ _v _menhir_s _tok
    
    and _menhir_run_398 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let sliced_basic_lexpr = _v in
        let _v = _menhir_action_102 sliced_basic_lexpr in
        _menhir_goto_discard_or_sliced_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_396 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LLBRACKET, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RRBRACKET -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_RRBRACKET (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, idx, _, _) = _menhir_stack in
        let MenhirCell1_LLBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, fields, _4) = ((), _v, ()) in
        let _v = _menhir_action_013 _2 _4 _endpos_desc_ _startpos_desc_ desc fields idx in
        _menhir_goto_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_sliced_basic_lexpr_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_sliced_basic_lexpr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState400 ->
            _menhir_run_406 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState402 ->
            _menhir_run_403 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_406 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_discard_or_sliced_basic_lexpr -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_sliced_basic_lexpr (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_060 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_211 _endpos__3_ _startpos__1_ x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_403 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_sliced_basic_lexpr, ttv_result) _menhir_cell1_discard_or_sliced_basic_lexpr -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_sliced_basic_lexpr (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_040 _2 h t in
        _menhir_goto_clist1_discard_or_sliced_basic_lexpr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_399 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_sliced_basic_lexpr (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState400 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_409 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_startpos__1_, _1) = (_startpos, ()) in
        let _v = _menhir_action_223 _1 in
        _menhir_goto_local_decl_keyword_non_var _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_local_decl_keyword_non_var : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_local_decl_keyword_non_var (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState461
        | Tokens.LPAR ->
            _menhir_run_316 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState461
        | Tokens.IDENTIFIER _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v_2 =
              let _1 = _v_0 in
              _menhir_action_093 _1
            in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState461 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_316 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState316 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_317 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_099 _1 in
        _menhir_goto_discard_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_identifier : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState322 ->
            _menhir_run_321 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState320 ->
            _menhir_run_321 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState316 ->
            _menhir_run_319 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_321 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState322 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_037 x in
            _menhir_goto_clist1_discard_or_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_318 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = _v in
        let _v = _menhir_action_100 _1 in
        _menhir_goto_discard_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_identifier_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState320 ->
            _menhir_run_324 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState322 ->
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_324 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_discard_or_identifier -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_identifier (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_059 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_094 _endpos__3_ _startpos__1_ x in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_323 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier, ttv_result) _menhir_cell1_discard_or_identifier -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_038 _2 h t in
        _menhir_goto_clist1_discard_or_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_319 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState320 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_410 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState410 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_413 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.LLBRACKET ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState413
        | Tokens.LBRACE ->
            let _menhir_s = MenhirState413 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState414 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, MenhirState413) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState416 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.MINUS ->
                    _menhir_run_417 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_418 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.LBRACKET ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState427 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_428 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer _v
            | _ ->
                _eRR ())
        | Tokens.EQ | Tokens.LBRACKET ->
            let _v_12 = _menhir_action_229 () in
            _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_417 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_097 _1 in
        _menhir_goto_discard_or_field _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_field : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState422 ->
            _menhir_run_421 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState420 ->
            _menhir_run_421 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState416 ->
            _menhir_run_419 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_421 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState422 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_417 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_418 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_035 x in
            _menhir_goto_clist1_discard_or_field_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_418 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_098 _endpos_desc_ _startpos_desc_ desc in
        _menhir_goto_discard_or_field _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_field_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState420 ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState422 ->
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_424 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_discard_or_field -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_field (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_058 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_214 _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_423 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field, ttv_result) _menhir_cell1_discard_or_field -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_036 _2 h t in
        _menhir_goto_clist1_discard_or_field_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_419 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState420 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_417 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_418 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_428 : type  ttv_stack ttv_result. (ttv_stack _menhir_cell0_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            _menhir_run_328 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR ()
    
    and _menhir_run_328 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState328 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_044 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState045 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON | Tokens.RBRACKET ->
            let x = _v in
            let _v = _menhir_action_033 x in
            _menhir_goto_clist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_IDENTIFIER_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState328 ->
            _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState229 ->
            _menhir_run_230 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState043 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState045 ->
            _menhir_run_046 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_329 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_057 _2 li x in
        _menhir_goto_clist2_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist2_IDENTIFIER_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState484 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState427 ->
            _menhir_run_429 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState314 ->
            _menhir_run_353 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_485 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_call _menhir_cell0_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_clist2_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState487 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_429 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_2, x, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_213 _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
            _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_353 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_clist2_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | _ ->
            _eRR ()
    
    and _menhir_run_230 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, x, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_188 _2 _endpos__3_ _startpos_e_ e x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_047 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, x, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_143 _2 _endpos__3_ _startpos_e_ e x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_046 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_034 _2 h t in
        _menhir_goto_clist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_431 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState433 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_441 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState442
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState442
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState442
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState442
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState442
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState442
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Tokens.RPAR ->
                let _v = _menhir_action_027 () in
                _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_443 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DEBUG _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_299 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_446 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_startpos__1_, _1) = (_startpos, ()) in
        let _v = _menhir_action_224 _1 in
        _menhir_goto_local_decl_keyword_non_var _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_447 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState447 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_455 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState455 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_list1_stmt_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState746 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState706 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState664 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState649 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState653 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState637 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState626 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState360 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState539 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState535 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState532 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState440 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState495 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState454 ->
            _menhir_run_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState459 ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_494 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_305 _1 in
        _menhir_goto_stmt_list _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_stmt_list : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState746 ->
            _menhir_run_748 _menhir_stack _v _tok
        | MenhirState712 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState706 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState664 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState653 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState649 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState637 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState626 ->
            _menhir_run_627 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_546 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState539 ->
            _menhir_run_540 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState535 ->
            _menhir_run_536 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState532 ->
            _menhir_run_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState360 ->
            _menhir_run_526 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState513 ->
            _menhir_run_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState440 ->
            _menhir_run_507 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState499 ->
            _menhir_run_500 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState495 ->
            _menhir_run_496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState454 ->
            _menhir_run_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_627 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_227 _1 in
        _menhir_goto_maybe_empty_stmt_list _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_maybe_empty_stmt_list : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState712 ->
            _menhir_run_713 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState706 ->
            _menhir_run_707 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState687 ->
            _menhir_run_688 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState681 ->
            _menhir_run_682 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState669 ->
            _menhir_run_670 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState664 ->
            _menhir_run_665 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState661 ->
            _menhir_run_662 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_658 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState653 ->
            _menhir_run_654 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState649 ->
            _menhir_run_650 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState637 ->
            _menhir_run_638 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState626 ->
            _menhir_run_628 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_713 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__2_) = _menhir_stack in
                let (_2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined1) = ((), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_067 _1_inlined1 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__2_) = _menhir_stack in
                let (_2, x, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = ((), _v, _endpos, _startpos, ()) in
                let _v = _menhir_action_068 _1_inlined1 _2 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_707 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__2_) = _menhir_stack in
                let (_2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined1) = ((), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_073 _1_inlined1 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__2_) = _menhir_stack in
                let (_2, x, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = ((), _v, _endpos, _startpos, ()) in
                let _v = _menhir_action_074 _1_inlined1 _2 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_688 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined2) = ((), (), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_069 _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_070 _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_682 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined2) = ((), (), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_075 _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_076 _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_670 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_GETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _2_inlined1, _4, _1_inlined1, _1_inlined2, setter) = ((), (), (), (), (), (), _v) in
                let _v = _menhir_action_003 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_GETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _4, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, setter) = ((), (), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_004 _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined2_ _startpos__1_inlined2_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_accessors : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState730 ->
            _menhir_run_731 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState698 ->
            _menhir_run_699 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState648 ->
            _menhir_run_673 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_731 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, accessors, _6) = ((), (), (), (), _v, ()) in
                let _v = _menhir_action_086 _1 _1_inlined1 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, accessors, _6) = ((), (), _endpos, _startpos, (), _v, ()) in
                let _v = _menhir_action_087 _1 _1_inlined1 _2 _6 _endpos__1_inlined1_ _startpos__1_inlined1_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_699 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, _1_inlined2, accessors, _6) = ((), (), (), (), (), _v, ()) in
                let _v = _menhir_action_088 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, accessors, _6) = ((), (), (), (), _endpos, _startpos, _v, ()) in
                let _v = _menhir_action_089 _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_673 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, _1_inlined2, accessors, _6) = ((), (), (), (), (), _v, ()) in
                let _v = _menhir_action_090 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, accessors, _6) = ((), (), (), (), _endpos, _startpos, _v, ()) in
                let _v = _menhir_action_091 _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_665 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_GETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _4, _1_inlined1, _1_inlined2, setter) = ((), (), (), (), (), _v) in
                let _v = _menhir_action_005 _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined1_ _startpos__1_inlined1_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_GETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _4, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, setter) = ((), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_006 _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_662 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_GETTER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_END (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.VAR ->
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.UNREACHABLE ->
                    _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.TRY ->
                    _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.THROW ->
                    _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.RETURN ->
                    _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.REPEAT ->
                    _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.PRINTLN ->
                    _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.PRINT ->
                    _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.PRAGMA ->
                    _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.PASS ->
                    _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.MINUS ->
                    _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.LPAR ->
                    _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.LET ->
                    _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.IF ->
                    _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.IDENTIFIER _v_1 ->
                    _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState664
                | Tokens.FOR ->
                    _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.DEBUG ->
                    _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.CONSTANT ->
                    _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.CASE ->
                    _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.ASSERT ->
                    _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                | Tokens.END ->
                    let _v_2 =
                      let _endpos__0_ = _endpos_0 in
                      _menhir_action_228 _endpos__0_
                    in
                    _menhir_run_665 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 _tok
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SETTER ->
                    let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.VAR ->
                        _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.UNREACHABLE ->
                        _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.TRY ->
                        _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.THROW ->
                        _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.RETURN ->
                        _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.REPEAT ->
                        _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.PRINTLN ->
                        _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.PRINT ->
                        _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.PRAGMA ->
                        _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.PASS ->
                        _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.MINUS ->
                        _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.LPAR ->
                        _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.LET ->
                        _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.IF ->
                        _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.IDENTIFIER _v_5 ->
                        _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState669
                    | Tokens.FOR ->
                        _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.DEBUG ->
                        _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.CONSTANT ->
                        _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.CASE ->
                        _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.ASSERT ->
                        _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState669
                    | Tokens.END ->
                        let _v_6 =
                          let _endpos__0_ = _endpos_4 in
                          _menhir_action_228 _endpos__0_
                        in
                        _menhir_run_670 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_658 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _4, _1_inlined1, _1_inlined2, getter) = ((), (), (), (), (), _v) in
                let _v = _menhir_action_009 _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined1_ _startpos__1_inlined1_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _4, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, getter) = ((), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_010 _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_654 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _2_inlined1, _4, _1_inlined1, _1_inlined2, getter) = ((), (), (), (), (), (), _v) in
                let _v = _menhir_action_007 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _4, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, getter) = ((), (), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_008 _1 _1_inlined1 _1_inlined2 _2 _4 _endpos__1_inlined2_ _startpos__1_inlined2_ getter setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_650 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_END (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.GETTER ->
                    let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.VAR ->
                        _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.UNREACHABLE ->
                        _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.TRY ->
                        _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.THROW ->
                        _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.RETURN ->
                        _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.REPEAT ->
                        _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.PRINTLN ->
                        _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.PRINT ->
                        _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.PRAGMA ->
                        _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.PASS ->
                        _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.MINUS ->
                        _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.LPAR ->
                        _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.LET ->
                        _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.IF ->
                        _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.IDENTIFIER _v_2 ->
                        _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState653
                    | Tokens.FOR ->
                        _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.DEBUG ->
                        _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.CONSTANT ->
                        _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.CASE ->
                        _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.ASSERT ->
                        _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState653
                    | Tokens.END ->
                        let _v_3 =
                          let _endpos__0_ = _endpos_1 in
                          _menhir_action_228 _endpos__0_
                        in
                        _menhir_run_654 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.GETTER ->
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.VAR ->
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.UNREACHABLE ->
                    _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.TRY ->
                    _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.THROW ->
                    _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.RETURN ->
                    _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.REPEAT ->
                    _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.PRINTLN ->
                    _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.PRINT ->
                    _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.PRAGMA ->
                    _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.PASS ->
                    _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.MINUS ->
                    _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.LPAR ->
                    _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.LET ->
                    _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.IF ->
                    _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.IDENTIFIER _v_5 ->
                    _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState657
                | Tokens.FOR ->
                    _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.DEBUG ->
                    _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.CONSTANT ->
                    _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.CASE ->
                    _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.ASSERT ->
                    _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState657
                | Tokens.END ->
                    let _v_6 =
                      let _endpos__0_ = _endpos_4 in
                      _menhir_action_228 _endpos__0_
                    in
                    _menhir_run_658 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_638 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined2) = ((), (), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_071 _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_072 _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_628 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _endpos__2_inlined1_, _2_inlined1, _1_inlined2) = ((), (), _v, _endpos_0, (), ()) in
                let _v = _menhir_action_077 _1 _1_inlined2 _2 _2_inlined1 _endpos__2_inlined1_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.PRAGMA | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _2, x, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_078 _1 _1_inlined2 _2 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_546 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_loop_limit -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_loop_limit (_menhir_stack, _, loop_limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _4, _1_inlined1, stmt_list) = ((), _endpos_1, (), (), (), _v) in
                let _v = _menhir_action_276 _1 _1_inlined1 _2 _4 _endpos__2_ _startpos__1_ expr loop_limit stmt_list in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_loop_limit (_menhir_stack, _, loop_limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _4, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, stmt_list) = ((), (), _endpos_0, _startpos, (), _v) in
                let _v = _menhir_action_277 _1 _1_inlined1 _4 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ expr loop_limit stmt_list in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_540 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_list1_catcher_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let (_1, _2, _3) = ((), (), _v) in
        let _v = _menhir_action_241 _1 _2 _3 in
        _menhir_goto_otherwise_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
    
    and _menhir_goto_otherwise_opt : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_list1_catcher_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_list1_catcher_ (_menhir_stack, _, c) = _menhir_stack in
                let MenhirCell1_stmt_list (_menhir_stack, _, s, _) = _menhir_stack in
                let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, o) = ((), _endpos_0, (), (), (), _v) in
                let _v = _menhir_action_280 _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ c o s in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_list1_catcher_ (_menhir_stack, _, c) = _menhir_stack in
                let MenhirCell1_stmt_list (_menhir_stack, _, s, _) = _menhir_stack in
                let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, o) = ((), (), _endpos, _startpos, (), _v) in
                let _v = _menhir_action_281 _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ c o s in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_536 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_1, _4, stmt_list) = ((), (), _v) in
        let _v = _menhir_action_025 _1 _4 stmt_list ty in
        _menhir_goto_catcher _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_catcher : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_catcher (_menhir_stack, _menhir_s, _v) in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState544
        | Tokens.END | Tokens.OTHERWISE ->
            let x = _v in
            let _v = _menhir_action_219 x in
            _menhir_goto_list1_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_528 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState528, _v, _startpos_0, _endpos) in
                let _menhir_s = MenhirState530 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.ARROW ->
                let _v =
                  let (_endpos_name_, _startpos_name_, name) = (_endpos, _startpos_0, _v) in
                  _menhir_action_329 _endpos_name_ _startpos_name_ name
                in
                _menhir_run_534 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState528 _tok
            | _ ->
                _eRR ())
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | _ ->
            _eRR ()
    
    and _menhir_run_534 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState535 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_list1_catcher_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState544 ->
            _menhir_run_545 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState527 ->
            _menhir_run_537 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_545 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_catcher -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_catcher (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_220 l x in
        _menhir_goto_list1_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_537 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_list1_catcher_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.OTHERWISE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState539 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINTLN ->
                    _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            let _v = _menhir_action_240 () in
            _menhir_goto_otherwise_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_533 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_1, _4, stmt_list) = ((), (), _v) in
        let _v = _menhir_action_026 _1 _4 stmt_list ty x in
        _menhir_goto_catcher _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_526 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_TRY as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.CATCH ->
            let _menhir_s = MenhirState527 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_521 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_REPEAT as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNTIL ->
            let _menhir_s = MenhirState522 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_516 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSE -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ELSE (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _endpos__2_, _2) = ((), _endpos, _v) in
        let _v = _menhir_action_260 _1 _2 in
        _menhir_goto_s_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_goto_s_else : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState510 ->
            _menhir_run_518 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState514 ->
            _menhir_run_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_518 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
                let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
                let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, s2) = ((), _endpos_1, (), (), (), _v) in
                let _v = _menhir_action_270 _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ e s1 s2 in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
                let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
                let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, s2) = ((), (), _endpos_0, _startpos, (), _v) in
                let _v = _menhir_action_271 _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ e s1 s2 in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_517 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_s2_, s2) = ((), (), _endpos, _v) in
        let _v = _menhir_action_258 _1 _3 _endpos_s2_ _startpos__1_ e s1 s2 in
        _menhir_goto_s_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s2_ _v _menhir_s _tok
    
    and _menhir_run_514 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState514
        | Tokens.ELSE ->
            _menhir_run_515 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState514
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_259 _endpos__0_
            in
            _menhir_run_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_511 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState511 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_515 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ELSE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState515 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_510 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState510
        | Tokens.ELSE ->
            _menhir_run_515 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState510
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_259 _endpos__0_
            in
            _menhir_run_518 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_507 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_loop_limit -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_loop_limit (_menhir_stack, _, limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
                let MenhirCell1_direction (_menhir_stack, _, dir) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
                let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, body, _1_inlined1, _8) = ((), _endpos_1, (), (), _v, (), ()) in
                let _v = _menhir_action_278 _1 _1_inlined1 _2 _3 _8 _endpos__2_ _startpos__1_ body dir end_e index_name limit start_e in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_loop_limit (_menhir_stack, _, limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
                let MenhirCell1_direction (_menhir_stack, _, dir) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
                let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, body, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _8) = ((), (), _v, _endpos_0, _startpos, (), ()) in
                let _v = _menhir_action_279 _1 _1_inlined1 _3 _8 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ body dir end_e index_name limit start_e in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_500 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF, ttv_result) _menhir_cell1_list1_case_alt_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_list1_case_alt_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _2_inlined1, _1_inlined3, otherwise_stmt, _1_inlined2) = ((), _endpos_1, (), (), (), (), _v, ()) in
                let _v = _menhir_action_274 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr otherwise_stmt in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_list1_case_alt_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _2_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3, otherwise_stmt, _1_inlined2) = ((), (), (), _endpos_0, _startpos, (), _v, ()) in
                let _v = _menhir_action_275 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ expr otherwise_stmt in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined3_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_496 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_pattern_list (_menhir_stack, _, pattern) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _4, _endpos_stmt_, stmt) = ((), (), _endpos, _v) in
        let _v = _menhir_action_023 _1 _4 _endpos_stmt_ _startpos__1_ pattern stmt in
        _menhir_goto_case_alt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_case_alt : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_case_alt (_menhir_stack, _menhir_s, _v) in
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.END | Tokens.OTHERWISE ->
            let x = _v in
            let _v = _menhir_action_217 x in
            _menhir_goto_list1_case_alt_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_450 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState450 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_040 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState040 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_052 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState052
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState052
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
            let _v = _menhir_action_246 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_pattern : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState055 ->
            _menhir_run_255 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState450 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_255 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState256 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_054 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_250 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_055 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState055 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_056 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState056 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_039 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState039 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_131 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState131 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_143 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState143
        | Tokens.LBRACE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState144
            | Tokens.REAL_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState144
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | Tokens.MINUS ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_5 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState145
                | Tokens.REAL_LIT _v_6 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState145
                | Tokens.RBRACE ->
                    let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_2, _3, _endpos_desc_, _startpos_desc_, desc, _endpos__4_, _4) = ((), (), _endpos, _startpos, _v, _endpos_7, ()) in
                    let _v = _menhir_action_196 _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc in
                    _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_desc_ _v _menhir_s _tok
                | Tokens.NOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.INT_LIT _v_8 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState145
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.IDENTIFIER _v_9 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState145
                | Tokens.BOOL_LIT _v_10 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState145
                | Tokens.BNOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | Tokens.BITVECTOR_LIT _v_11 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11 MenhirState145
                | Tokens.ARBITRARY ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState144, _startpos_3, _endpos_4) in
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
                | _ ->
                    _eRR ())
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | Tokens.INT_LIT _v_12 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState144
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | Tokens.IDENTIFIER _v_13 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState144
            | Tokens.BOOL_LIT _v_14 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState144
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | Tokens.BITVECTOR_LIT _v_15 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState144
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState143, _startpos_0) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
            | _ ->
                _eRR ())
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_155 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_147 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.SHL | Tokens.SHR | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_110 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_148 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState148 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_149 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_2, _3, _endpos__4_, _4) = ((), (), _endpos_0, ()) in
            let _v = _menhir_action_151 _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_desc_ _v _menhir_s _tok
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | _ ->
            _eRR ()
    
    and _menhir_run_154 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_EQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState154 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_170 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState170 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_172 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState172 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_173 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState173 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_174 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _menhir_s = MenhirState175 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_181 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState182 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_049 x in
            _menhir_goto_clist1_pattern_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_pattern_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState256 ->
            _menhir_run_257 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState450 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_251 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_257 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_pattern -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_pattern (_menhir_stack, _, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_062 _2 li x in
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_249 _endpos__3_ _startpos__1_ x in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_253 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_252 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_pattern_list _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_pattern_list : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState450 ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_262 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState173 ->
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_451 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_pattern_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHERE ->
            let _menhir_s = MenhirState452 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            let _menhir_s = MenhirState495 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_262 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_253 x in
            _menhir_goto_pattern_set _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_pattern_set : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState038 ->
            _menhir_run_264 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState216 ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState450 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_264 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_IN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_pattern_set_, pattern_set) = ((), _endpos, _v) in
        let _v = _menhir_action_146 _2 _endpos_pattern_set_ _startpos_expr_ expr pattern_set in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_pattern_set_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_run_218 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_IN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_IN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_pattern_set_, pattern_set) = ((), _endpos, _v) in
        let _v = _menhir_action_191 _2 _endpos_pattern_set_ _startpos_expr_pattern_ expr_pattern pattern_set in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_pattern_set_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_178 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_251 _1 in
        _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_179 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, x, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_254 _1 _endpos__3_ _startpos__1_ x in
            _menhir_goto_pattern_set _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_251 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_pattern -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_pattern (_menhir_stack, _menhir_s, h, _startpos_h_, _) = _menhir_stack in
        let (_2, _endpos_t_, t) = ((), _endpos, _v) in
        let _v = _menhir_action_050 _2 h t in
        _menhir_goto_clist1_pattern_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_h_ _v _menhir_s _tok
    
    and _menhir_goto_list1_case_alt_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState505 ->
            _menhir_run_506 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState449 ->
            _menhir_run_497 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_506 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_case_alt -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_case_alt (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_218 l x in
        _menhir_goto_list1_case_alt_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_497 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.OTHERWISE ->
            let _menhir_stack = MenhirCell1_list1_case_alt_ (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState499 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINTLN ->
                    _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, _1_inlined2) = ((), _endpos_1, (), (), _v, ()) in
                let _v = _menhir_action_272 _1 _1_inlined1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ expr in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_273 _1 _1_inlined1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ expr in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_458 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ARROW -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ARROW (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2, _, _) = _menhir_stack in
        let MenhirCell1_pattern_list (_menhir_stack, _, pattern) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _4, _1_inlined1, _endpos_stmt_, stmt) = ((), (), (), _endpos, _v) in
        let _v = _menhir_action_024 _1 _1_inlined1 _2 _4 _endpos_stmt_ _startpos__1_ pattern stmt in
        _menhir_goto_case_alt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_473 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_stmt -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_stmt (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_222 l x in
        _menhir_goto_list1_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _v _menhir_s _tok
    
    and _menhir_run_631 : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ARROW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState631 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_694 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BIARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState696 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_680 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState680) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState681
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_228 _endpos__0_
                in
                _menhir_run_682 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_631 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState680
        | _ ->
            _eRR ()
    
    and _menhir_run_644 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BIARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState646 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_625 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState625) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState626
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState626
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_228 _endpos__0_
                in
                _menhir_run_628 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_631 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState625
        | _ ->
            _eRR ()
    
    and _menhir_run_704 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_618 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState704
        | _ ->
            _eRR ()
    
    and _menhir_run_693 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_618 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState693
        | _ ->
            _eRR ()
    
    and _menhir_run_679 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_618 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState679
        | _ ->
            _eRR ()
    
    and _menhir_run_643 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_618 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState643
        | _ ->
            _eRR ()
    
    and _menhir_run_617 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_618 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState617
        | _ ->
            _eRR ()
    
    and _menhir_run_614 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_opt_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_opt_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_048 _2 h t in
        _menhir_goto_clist1_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_676 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.FUNC ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_1, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState678
                | Tokens.LPAR ->
                    let _v_2 = _menhir_action_242 () in
                    _menhir_run_679 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState678 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.ACCESSOR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_3, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState692
                | Tokens.LPAR ->
                    let _v_4 = _menhir_action_242 () in
                    _menhir_run_693 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState692 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_702 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
            | Tokens.LPAR ->
                let _v_1 = _menhir_action_242 () in
                _menhir_run_704 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState703 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_716 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_startpos__1_, _1) = (_startpos, ()) in
        let _v = _menhir_action_205 _1 in
        _menhir_goto_global_let_or_constant _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_717 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState717 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_554 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_555 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_723 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState724
            | Tokens.LPAR ->
                let _v_0 = _menhir_action_242 () in
                _menhir_run_725 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState724 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_058 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RDIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState058 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_031 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_POW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState031 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_060 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PLUS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState060 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_070 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_OR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState070 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_072 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_148 _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_e_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | _ ->
            _eRR ()
    
    and _menhir_run_062 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MUL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState062 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_064 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MOD (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState064 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_075 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState075 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_077 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState077 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_025 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState025 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_083 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState083 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_038 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IN (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState038 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BNOT ->
            _menhir_run_217 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_217 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IN as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState217 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_089 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IMPL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState089 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_085 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_GT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState085 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_087 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState087 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_091 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_147 _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_ expr in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_expr_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState091
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | _ ->
            _eRR ()
    
    and _menhir_run_042 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState043 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _endpos_x_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_142 _2 _endpos_x_ _startpos_e_ e x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_066 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIVRM (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState066 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_068 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState068 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_079 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState079 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_094 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState094 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_096 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BEQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState096 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_098 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BAND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState098 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_100 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState100 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_081 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState081 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_721 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_082 _1 _4 _endpos__2_ _startpos__1_ name ty x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState721
        | _ ->
            _eRR ()
    
    and _menhir_run_635 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState635
        | Tokens.BEGIN ->
            let MenhirCell1_RECURSELIMIT (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_256 _1 _2 in
            _menhir_goto_recurse_limit _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_recurse_limit : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState710 ->
            _menhir_run_711 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState685 ->
            _menhir_run_686 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState633 ->
            _menhir_run_636 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_686 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState687
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_228 _endpos__0_
            in
            _menhir_run_688 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_636 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState637
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState637
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_228 _endpos__0_
            in
            _menhir_run_638 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_559 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_option_as_ty_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_option_as_ty_ (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_083 _1 _4 _endpos__2_ _startpos__1_ name ty x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState559
        | _ ->
            _eRR ()
    
    and _menhir_run_523 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.LOOPLIMIT ->
            _menhir_run_310 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.SEMI_COLON ->
            let _v_0 = _menhir_action_225 () in
            _menhir_run_524 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_310 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState310 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_524 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_stmt_list (_menhir_stack, _, stmt_list, _) = _menhir_stack in
            let MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3, loop_limit) = ((), _endpos, (), _v) in
            let _v = _menhir_action_301 _1 _3 _endpos__2_ _startpos__1_ expr loop_limit stmt_list in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_512 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState512) in
            let _menhir_s = MenhirState513 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
        | _ ->
            _eRR ()
    
    and _menhir_run_492 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_call _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _2_inlined1, _4, rhs) = (_endpos_0, (), (), _v) in
            let _v = _menhir_action_290 _2_inlined1 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ desc fld rhs in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
        | _ ->
            _eRR ()
    
    and _menhir_run_488 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_call _menhir_cell0_LBRACKET, ttv_result) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist2_IDENTIFIER_ (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _2_inlined1, _4, rhs) = (_endpos_0, (), (), _v) in
            let _v = _menhir_action_291 _2_inlined1 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState488
        | _ ->
            _eRR ()
    
    and _menhir_run_481 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_call as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _2_inlined1, rhs) = (_endpos_0, (), _v) in
            let _v = _menhir_action_289 _2_inlined1 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
        | _ ->
            _eRR ()
    
    and _menhir_run_476 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_lexpr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_lexpr (_menhir_stack, _menhir_s, le, _startpos_le_) = _menhir_stack in
            let (_endpos__2_, _2_inlined1, e) = (_endpos_0, (), _v) in
            let _v = _menhir_action_288 _2_inlined1 _endpos__2_ _startpos_le_ e le in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState476
        | _ ->
            _eRR ()
    
    and _menhir_run_469 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_local_decl_keyword_non_var (_menhir_stack, _menhir_s, local_decl_keyword_non_var, _startpos_local_decl_keyword_non_var_) = _menhir_stack in
            let (_endpos__2_, _4, x_inlined1) = (_endpos_0, (), _v) in
            let _v = _menhir_action_287 _4 _endpos__2_ _startpos_local_decl_keyword_non_var_ decl_item local_decl_keyword_non_var x x_inlined1 in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | _ ->
            _eRR ()
    
    and _menhir_run_465 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_local_decl_keyword_non_var (_menhir_stack, _menhir_s, local_decl_keyword_non_var, _startpos_local_decl_keyword_non_var_) = _menhir_stack in
            let (_endpos__2_, x, _4) = (_endpos_0, _v, ()) in
            let _v = _menhir_action_286 _4 _endpos__2_ _startpos_local_decl_keyword_non_var_ decl_item local_decl_keyword_non_var x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | _ ->
            _eRR ()
    
    and _menhir_run_456 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ASSERT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos_0, _v) in
            let _v = _menhir_action_285 _1 _endpos__2_ _startpos__1_ e in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState456
        | _ ->
            _eRR ()
    
    and _menhir_run_453 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_ARROW (_menhir_stack, MenhirState453) in
            let _menhir_s = MenhirState454 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | _ ->
            _eRR ()
    
    and _menhir_run_448 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_CASE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.OF ->
            let _menhir_stack = MenhirCell1_OF (_menhir_stack, MenhirState448) in
            let _menhir_s = MenhirState449 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState448
        | _ ->
            _eRR ()
    
    and _menhir_run_438 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LOOPLIMIT ->
            _menhir_run_310 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState438
        | Tokens.DO ->
            let _v_0 = _menhir_action_225 () in
            _menhir_run_439 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState438 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_439 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loop_limit (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.DO ->
            let _menhir_s = MenhirState440 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_434 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.TO ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_menhir_s, _1) = (MenhirState434, ()) in
            let _v = _menhir_action_095 _1 in
            _menhir_goto_direction _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.DOWNTO ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_menhir_s, _1) = (MenhirState434, ()) in
            let _v = _menhir_action_096 _1 in
            _menhir_goto_direction _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
        | _ ->
            _eRR ()
    
    and _menhir_goto_direction : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_direction (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v_0 ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState437
        | Tokens.REAL_LIT _v_1 ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState437
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState437
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState437
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState437
        | Tokens.INT_LIT _v_2 ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState437
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState437
        | Tokens.IDENTIFIER _v_3 ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState437
        | Tokens.BOOL_LIT _v_4 ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState437
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState437
        | Tokens.BITVECTOR_LIT _v_5 ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState437
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState437
        | _ ->
            _eRR ()
    
    and _menhir_run_411 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState411) in
            let _menhir_s = MenhirState412 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState411
        | _ ->
            _eRR ()
    
    and _menhir_run_391 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RRBRACKET (_menhir_stack, MenhirState391, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.DOT ->
                _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState392
            | Tokens.COMMA | Tokens.EQ | Tokens.LBRACKET | Tokens.RPAR ->
                let _v_1 = _menhir_action_229 () in
                _menhir_run_396 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
        | _ ->
            _eRR ()
    
    and _menhir_run_368 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_RETURN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState368
        | Tokens.SEMI_COLON ->
            let x = _v in
            let _v = _menhir_action_237 x in
            _menhir_goto_option_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_363 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_THROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos_0, _v) in
            let _v = _menhir_action_302 _1 _endpos__2_ _startpos__1_ e in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState363
        | _ ->
            _eRR ()
    
    and _menhir_run_332 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState332
        | Tokens.SEMI_COLON ->
            let MenhirCell1_EQ (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_239 _1 _2 in
            _menhir_goto_option_eq_expr _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_option_eq_expr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState335 ->
            _menhir_run_351 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState330 ->
            _menhir_run_333 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_351 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos__2_, e) = ((), _endpos, _v) in
        let _v = _menhir_action_294 _1 _endpos__2_ _startpos__1_ e ldi x in
        _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_run_333 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos__2_, e) = ((), _endpos, _v) in
        let _v = _menhir_action_293 _1 _endpos__2_ _startpos__1_ e ldi in
        _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_run_311 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState311
        | Tokens.DO | Tokens.SEMI_COLON ->
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_226 _1 _2 in
            _menhir_goto_loop_limit _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_loop_limit : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState523 ->
            _menhir_run_524 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState438 ->
            _menhir_run_439 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState309 ->
            _menhir_run_312 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_312 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loop_limit (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.DO ->
            let _menhir_s = MenhirState313 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_309 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHILE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LOOPLIMIT ->
            _menhir_run_310 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DO ->
            let _v_0 = _menhir_action_225 () in
            _menhir_run_312 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState309 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_308 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_NOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState308
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState308
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState308
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState308
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_137 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_302 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_150 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState302) in
            let _menhir_s = MenhirState304 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | _ ->
            _eRR ()
    
    and _menhir_run_300 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.ELSIF ->
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.ELSE ->
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | _ ->
            _eRR ()
    
    and _menhir_run_135 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState135 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_139 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ELSE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState139 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_298 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState298) in
            let _menhir_s = MenhirState299 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState298
        | _ ->
            _eRR ()
    
    and _menhir_run_295 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState295
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState295
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState295
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState295
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_135 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_282 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SLICING as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState282
        | Tokens.COMMA | Tokens.RBRACE ->
            let MenhirCell1_SLICING (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_209 _2 e1 e2 in
            _menhir_goto_int_constraint _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_int_constraint : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_int_constraint (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState279 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_045 x in
            _menhir_goto_clist1_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_goto_clist1_int_constraint_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState020 ->
            _menhir_run_284 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState279 ->
            _menhir_run_283 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_284 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_063 x in
        _menhir_goto_constraint_kind _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_283 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_int_constraint -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_int_constraint (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_046 _2 h t in
        _menhir_goto_clist1_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_280 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_SLICING (_menhir_stack, MenhirState280) in
            let _menhir_s = MenhirState281 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState280
        | Tokens.COMMA | Tokens.RBRACE ->
            let expr = _v in
            let _v = _menhir_action_208 expr in
            _menhir_goto_int_constraint _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_273 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_262 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_slice : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_slice (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState266 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACKET ->
            let x = _v in
            let _v = _menhir_action_051 x in
            _menhir_goto_clist1_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_goto_clist1_slice_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState033 ->
            _menhir_run_275 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState266 ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_275 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_268 x in
        _menhir_goto_slices _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_slices : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState404 ->
            _menhir_run_405 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState258 ->
            _menhir_run_250 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState183 ->
            _menhir_run_250 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState125 ->
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState107 ->
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState741 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState721 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState635 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState559 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState523 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState411 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState512 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState448 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState453 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState492 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState488 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState481 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState476 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState469 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState465 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState456 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState438 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState434 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState391 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState368 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState363 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState332 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState309 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState311 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState308 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState302 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState298 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState300 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState295 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState280 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState282 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState024 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState026 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState028 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState030 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState032 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState267 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState273 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState271 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState269 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState035 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState037 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState254 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState249 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState244 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState242 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState240 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState238 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState236 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState234 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState227 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState224 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState222 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState220 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState215 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState212 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState210 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState208 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState206 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState204 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState202 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState199 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState197 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState195 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState193 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState191 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState189 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState187 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState185 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState171 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState157 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState155 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState132 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState134 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState136 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState138 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState140 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState057 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState105 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState117 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState099 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState097 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState095 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState090 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState093 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState074 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState088 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState086 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState084 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState078 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState082 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState080 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState076 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState071 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState061 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState069 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState067 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState065 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState063 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState059 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState053 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState041 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_405 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_basic_lexpr -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_basic_lexpr (_menhir_stack, _menhir_s, basic, _startpos_basic_) = _menhir_stack in
        let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_267 _endpos_desc_ _startpos_desc_ basic desc in
        _menhir_goto_sliced_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_basic_ _v _menhir_s _tok
    
    and _menhir_run_250 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_endpos_slices_, slices) = (_endpos, _v) in
        let _v = _menhir_action_185 _endpos_slices_ _startpos_e_ e slices in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_slices_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_111 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                let _menhir_stack = MenhirCell1_slices (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos_1, _endpos_2) in
                _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState112
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_slices (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos_1, _endpos_2) in
                _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState112
            | Tokens.COMMA | Tokens.RBRACE ->
                let (s, x) = (_v, _v_0) in
                let _v = _menhir_action_014 s x in
                _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_107 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState107 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RBRACE ->
            let _v = _menhir_action_311 () in
            _menhir_goto_tclist0_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist0_bitfield_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_017 x in
        _menhir_goto_bitfields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_goto_bitfields : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState106 ->
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState112 ->
            _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_128 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_019 _1 in
        _menhir_goto_bitfields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
    
    and _menhir_goto_bitfields_opt : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_BITS (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_bitfields_opt_, bitfields_opt) = ((), _endpos, _v) in
        let _v = _menhir_action_327 _1 _endpos_bitfields_opt_ _startpos__1_ bitfields_opt x in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_bitfields_opt_ _v _menhir_s _tok
    
    and _menhir_run_122 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slices _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_slices (_menhir_stack, _menhir_s, s, _, _) = _menhir_stack in
        let bf = _v in
        let _v = _menhir_action_015 bf s x in
        _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_bitfield : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _menhir_stack = MenhirCell1_bitfield (_menhir_stack, _menhir_s, _v) in
                _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState125
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_317 x x_inlined1 in
                _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_316 x in
            _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_bitfield_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState125 ->
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState107 ->
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_126 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_bitfield -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_bitfield (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_318 _2 h t in
        _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_108 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_312 _1 in
        _menhir_goto_tclist0_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_050 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_endpos_slices_, slices) = (_endpos, _v) in
        let _v = _menhir_action_140 _endpos_slices_ _startpos_e_ e slices in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_slices_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_274 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slice -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_slice (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_052 _2 h t in
        _menhir_goto_clist1_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_271 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState271
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_PLUS_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_263 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_269 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_STAR_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState269
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_STAR_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_265 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_267 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.STAR_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_STAR_COLON (_menhir_stack, MenhirState267) in
            let _menhir_s = MenhirState268 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.PLUS_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_PLUS_COLON (_menhir_stack, MenhirState267) in
            let _menhir_s = MenhirState270 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COLON (_menhir_stack, MenhirState267) in
            let _menhir_s = MenhirState272 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState267
        | Tokens.COMMA | Tokens.RBRACKET ->
            let expr = _v in
            let _v = _menhir_action_261 expr in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_254 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState254
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState254
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState254
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState254
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_180 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_249 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState249
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_AND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_156 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_244 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BAND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState244
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BAND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_157 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_242 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState242
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_159 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_240 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState240
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_158 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_238 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_COLON_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState238
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_COLON_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_179 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_236 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState236
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_160 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_234 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DIVRM as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState234
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIVRM (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_161 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_227 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_EQ_OP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState227
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_EQ_OP (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_163 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_224 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState224
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_166 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_222 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState222
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_GT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_165 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_220 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_IMPL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState220
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_IMPL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_167 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_215 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState215
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_169 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_212 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LLBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos__4_, _4, e2) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_186 _2 _4 _endpos__4_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_e1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState212
        | _ ->
            _eRR ()
    
    and _menhir_run_210 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState210
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_LT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_168 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_208 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState208
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_171 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_206 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState206
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MOD (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_172 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_204 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MUL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState204
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MUL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_173 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_202 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_NEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState202
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_NEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_164 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_199 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState199
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_OR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_174 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_197 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState197
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_PLUS (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_170 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_195 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_POW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState195
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_POW (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_178 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_193 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_RDIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState193
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_RDIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_175 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_191 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SHL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState191
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_176 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_189 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SHR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState189
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_177 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_187 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SLICING as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_SLICING (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_245 _2 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_185 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_XOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState185
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_XOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_162 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_171 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_expr_, expr) = ((), _endpos, _v) in
            let _v = _menhir_action_248 _1 _endpos_expr_ _startpos__1_ expr in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_157 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState157) in
            let _menhir_s = MenhirState158 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Tokens.RBRACE | Tokens.RPAR | Tokens.SEMI_COLON ->
            let x = _v in
            let _v = _menhir_action_041 x in
            _menhir_goto_clist1_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_expr_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState343 ->
            _menhir_run_344 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_305 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState602 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState442 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState381 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState376 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState371 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState338 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_344 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_clist1_expr_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_0 ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState346
                | Tokens.REAL_LIT _v_1 ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState346
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState346
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState346
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState346
                | Tokens.INT_LIT _v_2 ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState346
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState346
                | Tokens.IDENTIFIER _v_3 ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState346
                | Tokens.BOOL_LIT _v_4 ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState346
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState346
                | Tokens.BITVECTOR_LIT _v_5 ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState346
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState346
                | Tokens.RPAR ->
                    let _v_6 = _menhir_action_027 () in
                    _menhir_run_347 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _3, _endpos__5_, _5, params) = ((), (), _endpos, (), _v) in
                let _v = _menhir_action_107 _2 _3 _5 name params in
                _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _startpos_name_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_347 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist1_expr_ (_menhir_stack, _, params) = _menhir_stack in
            let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (_2, x, _3, _endpos__3_inlined1_, _5) = ((), _v, (), _endpos, ()) in
            let _v = _menhir_action_108 _2 _3 _5 name params x in
            _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_elided_param_call : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState468 ->
            _menhir_run_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState336 ->
            _menhir_run_349 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_471 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
            let MenhirCell1_local_decl_keyword_non_var (_menhir_stack, _menhir_s, ldk, _startpos_ldk_) = _menhir_stack in
            let (_endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = (_endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_292 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ _startpos_ldk_ desc ldk lhs ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_349 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty, ttv_result) _menhir_cell1_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_296 _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_305 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_061 _2 li x in
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_153 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_165 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_028 _1 in
        _menhir_goto_clist0_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist0_expr_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState602 ->
            _menhir_run_603 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState442 ->
            _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState381 ->
            _menhir_run_382 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState376 ->
            _menhir_run_377 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState371 ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState346 ->
            _menhir_run_347 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState340 ->
            _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState010 ->
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState164 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_341 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (_2, x, _3, _endpos__3_inlined1_) = ((), _v, (), _endpos) in
            let _v = _menhir_action_106 _2 _3 name x in
            _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_296 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_020 name x in
            _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_call : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState746 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState706 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState661 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState669 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState664 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState649 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState657 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState653 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState637 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState626 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState313 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState360 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState539 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState535 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState532 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState440 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState495 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState454 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState459 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState450 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState055 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState256 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState182 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState740 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState720 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState634 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState602 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState558 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState522 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState410 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState433 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState437 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState447 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState452 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState491 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState475 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState442 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState390 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState381 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState376 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState371 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState365 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState361 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState336 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState338 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState343 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState346 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState331 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState310 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState299 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState279 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState025 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState027 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState029 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState031 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState033 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState266 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState272 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState270 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState268 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState172 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState248 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState243 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState241 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState239 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState237 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState235 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState233 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState225 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState223 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState219 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState214 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState211 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState209 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState207 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState205 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState203 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState200 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState198 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState194 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState192 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState190 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState188 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState186 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState170 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState144 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState148 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState164 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState158 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState154 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState116 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState089 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState091 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState087 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState085 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState083 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState077 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState081 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState079 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState075 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState052 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_478 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__2_, _startpos_call_, call) = (_endpos_0, _startpos, _v) in
            let _v = _menhir_action_284 _endpos__2_ _startpos_call_ call in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_call (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState480 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_call (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState484 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_428 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EQ ->
                    let _menhir_s = MenhirState491 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.STRING_LIT _v ->
                        _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.REAL_LIT _v ->
                        _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.NOT ->
                        _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.MINUS ->
                        _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INT_LIT _v ->
                        _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.IF ->
                        _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOL_LIT _v ->
                        _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BNOT ->
                        _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITVECTOR_LIT _v ->
                        _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.ARBITRARY ->
                        _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_252 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_call_, _startpos_call_, call) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_184 _endpos_call_ _startpos_call_ call in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_call_ _startpos_call_ _v _menhir_s _tok
    
    and _menhir_run_051 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_call_, _startpos_call_, call) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_139 _endpos_call_ _startpos_call_ call in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_call_ _startpos_call_ _v _menhir_s _tok
    
    and _menhir_run_166 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist1_expr_ (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (x_inlined1, _endpos__3_inlined1_) = (_v, _endpos) in
            let _v = _menhir_action_022 name x x_inlined1 in
            _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_162 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_clist1_expr_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_0 ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState164
                | Tokens.REAL_LIT _v_1 ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState164
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.INT_LIT _v_2 ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState164
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.IDENTIFIER _v_3 ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState164
                | Tokens.BOOL_LIT _v_4 ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState164
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.BITVECTOR_LIT _v_5 ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState164
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState164
                | Tokens.RPAR ->
                    let _v_6 = _menhir_action_027 () in
                    _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                | _ ->
                    _eRR ())
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
                let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (x, _endpos__3_) = (_v, _endpos) in
                let _v = _menhir_action_021 name x in
                _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_159 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_042 _2 h t in
        _menhir_goto_clist1_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_155 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Tokens.COMMA | Tokens.RBRACE ->
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let y = _v in
            let _v = _menhir_action_198 x y in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_field_assign (_menhir_stack, _menhir_s, _v) in
                let _menhir_s = MenhirState152 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_s = MenhirState153 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.EQ ->
                        _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.RBRACE ->
                let x = _v in
                let _v = _menhir_action_043 x in
                _menhir_goto_clist1_field_assign_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _menhir_fail ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_field_assign_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState144 ->
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState338 ->
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState148 ->
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState152 ->
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_168 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_197 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_160 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_152 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_156 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_field_assign -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_field_assign (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_044 _2 h t in
        _menhir_goto_clist1_field_assign_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_140 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState140
        | Tokens.ARROW | Tokens.BEGIN | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_ELSE (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _endpos__2_, _2) = ((), _endpos, _v) in
            let _v = _menhir_action_103 _1 _2 in
            _menhir_goto_e_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_e_else : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState300 ->
            _menhir_run_301 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState134 ->
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState138 ->
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_301 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_138 _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_142 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_183 _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_141 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, c, _, _) = _menhir_stack in
        let MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e2_, e2) = ((), (), _endpos, _v) in
        let _v = _menhir_action_104 _1 _3 _endpos_e2_ _startpos__1_ c e1 e2 in
        _menhir_goto_e_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _v _menhir_s _tok
    
    and _menhir_run_138 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.ELSIF ->
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.ELSE ->
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState138
        | _ ->
            _eRR ()
    
    and _menhir_run_136 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState136) in
            let _menhir_s = MenhirState137 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState136
        | _ ->
            _eRR ()
    
    and _menhir_run_134 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.ELSIF ->
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.ELSE ->
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState134
        | _ ->
            _eRR ()
    
    and _menhir_run_132 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState132) in
            let _menhir_s = MenhirState133 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState132
        | _ ->
            _eRR ()
    
    and _menhir_run_117 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ARRAY as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.RRBRACKET ->
            let _menhir_s = MenhirState117 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RRBRACKET (_menhir_stack, _menhir_s, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.OF ->
                let _menhir_s = MenhirState119 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState117
        | _ ->
            _eRR ()
    
    and _menhir_run_105 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.SHR ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.SHL ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.RPAR ->
            let _menhir_s = MenhirState105 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, _menhir_s, _endpos) in
            let _menhir_s = MenhirState106 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RECURSELIMIT | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.SUBTYPES | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
                let _v = _menhir_action_018 () in
                _menhir_goto_bitfields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.POW ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.PLUS ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.OR ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.NEQ ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.MUL ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.MOD ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.MINUS ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.LT ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.LLBRACKET ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.LEQ ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.LBRACKET ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.IN ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.IMPL ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.GT ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.GEQ ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.EQ_OP ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.DOT ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.DIVRM ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.DIV ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.COLON_COLON ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.BOR ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.BEQ ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.BAND ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.AS ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | Tokens.AND ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState105
        | _ ->
            _eRR ()
    
    and _menhir_run_099 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BAND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState099
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BAND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_112 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_097 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState097
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_114 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_095 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState095
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_113 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_093 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_EQ_OP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState093
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_EQ_OP (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_118 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_090 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IMPL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_IMPL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_122 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_088 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_121 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_086 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_GT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_120 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_084 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_124 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_082 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_AND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_111 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_080 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_COLON_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_134 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_078 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_LT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_123 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_076 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_126 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_074 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_NEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_NEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_119 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_071 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState071
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_OR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_129 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_069 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState069
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_115 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_067 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DIVRM as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState067
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIVRM (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_116 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_065 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState065
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MOD (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_127 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_063 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MUL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState063
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MUL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_128 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_061 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState061
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_PLUS (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_125 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_059 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RDIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState059
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_RDIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_130 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_057 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState057
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_expr_, expr) = ((), _endpos, _v) in
            let _v = _menhir_action_247 _1 _endpos_expr_ _startpos__1_ expr in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_053 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_181 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_041 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_NOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState041
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState041
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState041
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState041
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_182 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_037 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SHL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_131 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_035 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState035
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_COLON (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, e) = ((), _v) in
            let _v = _menhir_action_264 _1 e in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_032 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_POW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState032
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState032
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState032
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState032
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_POW (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_133 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_030 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SHR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState030
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_132 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_028 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_XOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_XOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_117 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_026 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LLBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos__4_, _4, e2) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_141 _2 _4 _endpos__4_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_e1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState026
        | _ ->
            _eRR ()
    
    and _menhir_run_024 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState024
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState024
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState024
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState024
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_136 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist0_ty_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_328 _endpos__3_ _startpos__1_ x in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_run_330 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState330) in
            let _menhir_s = MenhirState331 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState330
        | Tokens.SEMI_COLON ->
            let _v_6 = _menhir_action_238 () in
            _menhir_run_333 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | _ ->
            _eRR ()
    
    and _menhir_run_685 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_634 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState685
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_255 () in
            _menhir_run_686 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState685
        | _ ->
            _eRR ()
    
    and _menhir_run_633 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_634 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState633
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_255 () in
            _menhir_run_636 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState633
        | _ ->
            _eRR ()
    
    and _menhir_run_598 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_331 _1 in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_531 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState532 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_294 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ARBITRARY -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_149 _1 _2 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_288 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState289 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_053 x in
            _menhir_goto_clist1_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_ty_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState018 ->
            _menhir_run_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState289 ->
            _menhir_run_290 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_291 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_030 _1 in
        _menhir_goto_clist0_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_290 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _menhir_s, h, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_054 _2 h t in
        _menhir_goto_clist1_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_246 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_ty_, ty) = ((), _endpos, _v) in
        let _v = _menhir_action_189 _2 _endpos_ty_ _startpos_expr_pattern_ expr_pattern ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_176 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ARBITRARY -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_194 _1 _2 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_129 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_ty_, ty) = ((), _endpos, _v) in
        let _v = _menhir_action_144 _2 _endpos_ty_ _startpos_expr_ expr ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_run_121 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COLON (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _2) = ((), _v) in
        let _v = _menhir_action_011 _1 _2 in
        _menhir_goto_as_ty _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_as_ty : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState738 ->
            _menhir_run_743 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState728 ->
            _menhir_run_729 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState718 ->
            _menhir_run_719 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState696 ->
            _menhir_run_697 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState646 ->
            _menhir_run_647 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState610 ->
            _menhir_run_611 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState571 ->
            _menhir_run_572 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState556 ->
            _menhir_run_561 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_467 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState353 ->
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState330 ->
            _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_743 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_global_let_or_constant, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let x = _v in
        let _v = _menhir_action_235 x in
        _menhir_goto_option_as_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_option_as_ty_ : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState738 ->
            _menhir_run_739 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState556 ->
            _menhir_run_557 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_729 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _menhir_s = MenhirState730 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_649 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.GETTER ->
                _menhir_run_661 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_649 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_SETTER (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState649
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState649
        | Tokens.END ->
            let _v =
              let _endpos__0_ = _endpos in
              _menhir_action_228 _endpos__0_
            in
            _menhir_run_650 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState649 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_661 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_GETTER (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState661
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState661
        | Tokens.END ->
            let _v =
              let _endpos__0_ = _endpos in
              _menhir_action_228 _endpos__0_
            in
            _menhir_run_662 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState661 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_719 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState720 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_697 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _menhir_s = MenhirState698 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_649 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.GETTER ->
                _menhir_run_661 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_647 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _menhir_s = MenhirState648 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_649 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.GETTER ->
                _menhir_run_661 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_611 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let x_inlined1 = _v in
        let _v = _menhir_action_233 x x_inlined1 in
        _menhir_goto_opt_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_572 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let y = _v in
        let _v = _menhir_action_336 x y in
        _menhir_goto_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_typed_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState620 ->
            _menhir_run_619 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState618 ->
            _menhir_run_619 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState574 ->
            _menhir_run_573 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState568 ->
            _menhir_run_573 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_619 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState620 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_571 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_055 x in
            _menhir_goto_clist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState618 ->
            _menhir_run_622 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState620 ->
            _menhir_run_621 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_622 : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_032 _1 in
        _menhir_goto_clist0_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_621 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_056 _2 h t in
        _menhir_goto_clist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_573 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, _v) in
                _menhir_run_571 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState574
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_320 x x_inlined1 in
                _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_319 x in
            _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState568 ->
            _menhir_run_576 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState574 ->
            _menhir_run_575 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_576 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_200 x in
        _menhir_goto_fields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_run_575 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_321 _2 h t in
        _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_561 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_084 _1 _endpos__2_ _startpos__1_ name x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.EQ ->
            let x = _v in
            let _v = _menhir_action_235 x in
            _menhir_goto_option_as_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_467 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_local_decl_keyword_non_var, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState468 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_337 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_337 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState337
        | Tokens.LBRACE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState338
            | Tokens.REAL_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState338
            | Tokens.RBRACE ->
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                    let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState338, _endpos_3) in
                    let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.STRING_LIT _v_5 ->
                        _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState340
                    | Tokens.REAL_LIT _v_6 ->
                        _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState340
                    | Tokens.NOT ->
                        _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState340
                    | Tokens.MINUS ->
                        _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState340
                    | Tokens.LPAR ->
                        _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState340
                    | Tokens.INT_LIT _v_7 ->
                        _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState340
                    | Tokens.IF ->
                        _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState340
                    | Tokens.IDENTIFIER _v_8 ->
                        _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState340
                    | Tokens.BOOL_LIT _v_9 ->
                        _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState340
                    | Tokens.BNOT ->
                        _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState340
                    | Tokens.BITVECTOR_LIT _v_10 ->
                        _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState340
                    | Tokens.ARBITRARY ->
                        _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState340
                    | Tokens.RPAR ->
                        let _v_11 = _menhir_action_027 () in
                        _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11 _tok
                    | _ ->
                        _eRR ())
                | Tokens.SEMI_COLON ->
                    let (_2, _startpos_name_, name, _endpos__3_, _3) = ((), _startpos, _v, _endpos_3, ()) in
                    let _v = _menhir_action_105 _2 _3 name in
                    _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState338
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState338
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState338
            | Tokens.INT_LIT _v_12 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState338
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState338
            | Tokens.IDENTIFIER _v_13 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState338
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState338) in
                let _menhir_s = MenhirState343 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_20 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_20 MenhirState338
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState338
            | Tokens.BITVECTOR_LIT _v_21 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_21 MenhirState338
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState337, _startpos_0) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState338
            | _ ->
                _eRR ())
        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_110 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_354 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_clist2_IDENTIFIER_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_clist2_IDENTIFIER_ (_menhir_stack, _, _2_inlined1) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, as_ty) = ((), _endpos, _v) in
            let _v = _menhir_action_295 _1 _2_inlined1 _endpos__2_ _startpos__1_ as_ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_335 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState335) in
            let _menhir_s = MenhirState336 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_337 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SEMI_COLON ->
            let _v_6 = _menhir_action_238 () in
            _menhir_run_351 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | _ ->
            _eRR ()
    
    and _menhir_run_123 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slices _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_slices (_menhir_stack, _menhir_s, s, _, _) = _menhir_stack in
        let ty = _v in
        let _v = _menhir_action_016 s ty x in
        _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_120 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_ARRAY, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RRBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RRBRACKET (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_ARRAY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _4, _endpos_t_, t, _5) = ((), (), (), _endpos, _v, ()) in
        let _v = _menhir_action_330 _1 _2 _4 _5 _endpos_t_ _startpos__1_ e t in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _menhir_s _tok
    
    and _menhir_run_186 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SLICING (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState186 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_188 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState188 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_190 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState190 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_192 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RDIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState192 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_194 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_POW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState194 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_196 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PLUS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState196 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_198 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_OR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState198 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_200 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_193 _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_e_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState200
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | _ ->
            _eRR ()
    
    and _menhir_run_203 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MUL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState203 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_205 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MOD (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState205 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_207 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState207 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_209 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState209 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_211 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState211 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_214 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState214 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_216 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IN (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState216 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BNOT ->
            _menhir_run_217 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_219 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IMPL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState219 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_221 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_GT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState221 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_223 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState223 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_225 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_192 _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_expr_pattern_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState225
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | _ ->
            _eRR ()
    
    and _menhir_run_228 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState229 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _endpos_x_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_187 _2 _endpos_x_ _startpos_e_ e x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_233 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIVRM (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState233 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_235 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState235 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_237 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState237 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_239 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState239 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_241 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BEQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState241 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_243 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BAND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState243 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_245 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState245 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_248 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState248 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_183 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_186 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_192 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_221 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_225 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_228 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_233 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_235 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_237 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_239 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_241 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_243 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_245 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_248 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState183
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos_expr_pattern_, _startpos_expr_pattern_, expr_pattern) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_244 _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_pattern_ _startpos_expr_pattern_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_023 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_value_, _startpos_value_, value) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_109 _endpos_value_ _startpos_value_ value in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_value_ _startpos_value_ _v _menhir_s _tok
    
    let _menhir_run_000 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState000 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    let _menhir_run_552 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_553 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.TYPE ->
            _menhir_run_563 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.PRAGMA ->
            _menhir_run_601 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.LET ->
            _menhir_run_605 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.IMPLEMENTATION ->
            _menhir_run_606 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.IMPDEF ->
            _menhir_run_676 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.FUNC ->
            _menhir_run_702 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.CONSTANT ->
            _menhir_run_716 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.CONFIG ->
            _menhir_run_717 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.ACCESSOR ->
            _menhir_run_723 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState552
        | Tokens.EOF ->
            let _v = _menhir_action_215 () in
            _menhir_run_735 _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_746 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_stmts =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState746 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
  end
  
  let stmts =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_stmts v = _menhir_run_746 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let spec =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_spec v = _menhir_run_552 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let opn =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_opn v = _menhir_run_000 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
end
